<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'activer_plugin' => 'Activar o m&oacute;dulo',
'affichage' => 'Presentaci&oacute;n',
'aide_non_disponible' => 'Esta parte da axuda en li&ntilde;a a&iacute;nda non est&aacute; dispo&ntilde;ible nesta lingua.',
'auteur' => 'Autor&nbsp;:',
'avis_acces_interdit' => 'Acceso prohibido.',
'avis_article_modifie' => 'Atenci&oacute;n, @nom_auteur_modif@ estaba traballando neste artigo hai @date_diff@ minutos',
'avis_aucun_resultat' => 'Ning&uacute;n resultado.',
'avis_chemin_invalide_1' => 'A rota que elixiches',
'avis_chemin_invalide_2' => 'non semella ser v&aacute;lida. Volva &aacute; p&aacute;xina anterior e verifique as informaci&oacute;ns introducidas.',
'avis_connexion_echec_1' => 'A conexi&oacute;n &aacute; base de datos non vai.',
'avis_connexion_echec_2' => 'Volva &aacute; p&aacute;xina anterior, e verifique as informaci&oacute;ns introducidas.',
'avis_connexion_echec_3' => '<b>N.B.</b> En moitos servidores, ter&aacute; que <b>pedir</b> a activaci&oacute;n do seu acceso &aacute; base SQL antes de podela usar. Se non d&aacute; conectado, verifique ter dado ese paso.',
'avis_connexion_ldap_echec_1' => 'A conexi&oacute;n ao servidor LDAP fallou.',
'avis_connexion_ldap_echec_2' => 'Volva &aacute; p&aacute;xina anterior, e verifique as informaci&oacute;ns introducidas.',
'avis_connexion_ldap_echec_3' => 'Como alternativa, non empregue o sistema LDAP para importar redactores.',
'avis_conseil_selection_mot_cle' => '<b>Grupo importante:</b>&eacute; moi aconsellable seleccionar unha palabra chave neste grupo.',
'avis_deplacement_rubrique' => 'Atenci&oacute;n! Este tema cont&eacute;n @contient_breves@ breve@scb@: se a(s) quere desprazar, conf&iacute;rmeo aqu&iacute;.',
'avis_destinataire_obligatoire' => 'Tes que indicar o destino antes de enviar esta mensaxe.',
'avis_doublon_mot_cle' => 'Xa existe unha palabra con ese t&iacute;tulo. Est&aacute; seguro de que quere crear o mesmo?',
'avis_erreur_connexion_mysql' => 'Erro de conexi&oacute;n SQL',
'avis_erreur_version_archive' => '<b>Atenci&oacute;n! O ficheiro @arquivo@ corresponde a
  outra versi&oacute;n de SPIP que non &eacute; a que ten instalada.</b>
  Pode estar ante graves problemas: hai risco de destruci&oacute;n
  da s&uacute;a base de datos, erros no funcionamento do web, etc.
  Non valide esta solicitude de importaci&oacute;n.<p>Para m&aacute;is
  informaci&oacute;ns, consulte <a href="@spipnet@">
  a documentaci&oacute;n de SPIP</A>.</p>',
'avis_espace_interdit' => '<b>Espazo prohibido</b><div>SPIP xa est&aacute; instalado.</div>',
'avis_lecture_noms_bases_1' => 'O programa de instalaci&oacute;n non puido ler os nomes das bases de datos instaladas.',
'avis_lecture_noms_bases_2' => 'Pode que non haxa ningunha base dispo&ntilde;&iacute;bel, ou que a funci&oacute;n que lista as bases estea desactivada por motivos de seguridade (caso moi frecuente en moitos provedores de servizos).',
'avis_lecture_noms_bases_3' => 'Na segunda alternativa, &eacute; prob&aacute;bel que unha base co seu nome de identificador poida ser empregada:',
'avis_non_acces_message' => 'Non tes acceso a esta mensaxe.',
'avis_non_acces_page' => 'Non tes acceso a esta p&aacute;xina.',
'avis_operation_echec' => 'Fallou a operaci&oacute;n.',
'avis_operation_impossible' => 'Operaci&amp;oacute;n impos&amp;iacute;bel',
'avis_probleme_archive' => 'Problema de leitura do ficheiro @archive@',
'avis_site_introuvable' => 'Non se pode atopar o web',
'avis_site_syndique_probleme' => 'Atenci&oacute;n: a afiliaci&oacute;n deste web atopou un problema; o sistema quedou temporalmente interrompido. Verifique o enderezo do ficheiro de afiliaci&oacute;n deste web (<b>@url_syndic@</b>), e tente unha nova recuperaci&oacute;n da informaci&oacute;n.',
'avis_sites_probleme_syndication' => 'Estes webs atoparon un problema de afiliaci&oacute;n',
'avis_sites_syndiques_probleme' => 'Estes webs afiliados devolveron un problema',
'avis_suppression_base' => 'ATENCI&Oacute;N, a supresi&oacute;n dos datos &eacute; irreversible',
'avis_version_mysql' => 'A s&uacute;a versi&oacute;n de SQL (@version_mysql@) non permite a auto-reparaci&oacute;n das t&aacute;boas da base de datos.',

// B
'bouton_acces_ldap' => 'Engadir o acceso a LDAP',
'bouton_ajouter' => 'Engadir',
'bouton_ajouter_participant' => 'ENGADIR PARTICIPANTE:',
'bouton_annonce' => 'ANUNCIO',
'bouton_annuler' => 'Anular',
'bouton_checkbox_envoi_message' => 'posibilidade de enviar unha mensaxe',
'bouton_checkbox_indiquer_site' => 'indicar obrigatoriamente un web',
'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'o equipo de xesti&oacute;n do web',
'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'o equipo de redacci&oacute;n',
'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'visitantes do web p&uacute;blico cando escriben unha mensaxe nun foro.',
'bouton_checkbox_signature_unique_email' => 'unha soa sinatura por cada enderezo de correo-e',
'bouton_checkbox_signature_unique_site' => 'unha soa sinatura por cada web',
'bouton_demande_publication' => 'Solicitar a publicaci&oacute;n deste artigo',
'bouton_desactive_tout' => 'Desactivar todo',
'bouton_desinstaller' => 'Desinstalar',
'bouton_effacer_index' => 'Borrar os &iacute;ndices',
'bouton_effacer_statistiques' => 'Borrar as estat&iacute;sticas',
'bouton_effacer_tout' => 'Borrar TODO',
'bouton_envoi_message_02' => 'ENVIAR UNHA MENSAXE',
'bouton_envoyer_message' => 'Mensaxe definitiva: enviar',
'bouton_forum_petition' => 'FORO e PETICI&Oacute;N',
'bouton_modifier' => 'Modificar',
'bouton_pense_bete' => 'NOTA PARA USO PERSOAL',
'bouton_radio_activer_messagerie' => 'Activar a mensaxer&iacute;a interna',
'bouton_radio_activer_messagerie_interne' => 'Activar a mensaxer&iacute;a interna',
'bouton_radio_activer_petition' => 'Activar a petici&oacute;n',
'bouton_radio_afficher' => 'Mostrar',
'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Aparecer na lista de redactores conectados',
'bouton_radio_articles_futurs' => 's&oacute; aos artigos futuros (non modificar nin facer nada na base de datos).',
'bouton_radio_articles_tous' => 'a todos os artigos sen excepci&oacute;n.',
'bouton_radio_articles_tous_sauf_forum_desactive' => 'a todos os artigos, ag&aacute;s &oacute;s que te&ntilde;an o foro desactivado;.',
'bouton_radio_desactiver_messagerie' => 'Desactivar a mensaxer&iacute;a',
'bouton_radio_enregistrement_obligatoire' => 'Rexistro obrigatorio (se quere usar este servizo
  ten que se rexistrar co seu enderezo de correo-e. antes de
  poder achegar contribuci&oacute;ns).',
'bouton_radio_envoi_annonces_adresse' => 'Enviar os anuncios ao enderezo:',
'bouton_radio_envoi_liste_nouveautes' => 'Enviar a lista de novidades',
'bouton_radio_moderation_priori' => 'Moderado a priori (as
  contribuci&oacute;ns ser&aacute;n publicadas trala aprobaci&oacute;n do grupo xestor).',
'bouton_radio_modere_abonnement' => 'con subscrici&oacute;n',
'bouton_radio_modere_posteriori' => 'moderaci&oacute;n a posteriori',
'bouton_radio_modere_priori' => 'moderaci&oacute;n a priori',
'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Non aparecer na lista de redactores que publica',
'bouton_radio_non_envoi_annonces_editoriales' => 'Non enviar as novidades editoriais',
'bouton_radio_non_syndication' => 'Sen afiliaci&oacute;n',
'bouton_radio_pas_petition' => 'Sen petici&oacute;n',
'bouton_radio_petition_activee' => 'Petici&oacute;n activada',
'bouton_radio_publication_immediate' => 'Publicaci&oacute;n inmediata das mensaxes
		(as contribuci&oacute;ns am&oacute;sanse dende o seu env&iacute;o, o equipo de xesti&oacute;n p&oacute;deas borrar).',
'bouton_radio_sauvegarde_compressee' => 'copia de seguridade comprimida en @fichier@',
'bouton_radio_sauvegarde_non_compressee' => 'copia de seguridade sen comprimir en @fichier@',
'bouton_radio_supprimer_petition' => 'Eliminar a petici&oacute;n',
'bouton_radio_syndication' => 'Afiliaci&oacute;n:',
'bouton_redirection' => 'REDIRECCI&Oacute;N',
'bouton_relancer_installation' => 'Relanzar a instalaci&oacute;n',
'bouton_restaurer_base' => 'Restaurar a base',
'bouton_suivant' => 'Seguinte',
'bouton_tenter_recuperation' => 'Tentar unha reparaci&oacute;n',
'bouton_test_proxy' => 'Probar o proxy',
'bouton_vider_cache' => 'Baleirar a memoria cach&eacute;',
'bouton_voir_message' => 'Ver a mensaxe antes de validala',

// C
'cache_mode_compresse' => 'Os ficheiros da memoria cach&eacute; est&aacute;n rexistrados en modo comprimido.',
'cache_mode_non_compresse' => 'Os ficheiros da memoria cach&eacute; est&aacute;n rexistrados en modo non comprimido',
'cache_modifiable_webmestre' => 'Este par&aacute;metro &eacute; modific&aacute;bel polo webm&aacute;ster do web.',
'calendrier_synchro' => 'Se usa un programa de axenda compatible <b>iCal</b>, poder&aacute; sincronizalo coas informaci&oacute;ns deste web.',
'config_activer_champs' => 'Activar os seguintes campos',
'config_choix_base_sup' => 'escolla unha base de datos deste servidor',
'config_erreur_base_sup' => 'SPIP non ten acceso &aacute; lista de bases de datos accesibles',
'config_info_base_sup' => 'Se ten outras bases de datos para consultas a trav&eacute;s de SPIP, co seu servidor SQL ou con outro, o formulario seguinte permitiralle declaralas. Se deixa certos campos baleiros, os identificadores de conexi&oacute;n &aacute; base de datos principal ser&aacute;n os utilizados.',
'config_info_base_sup_disponibles' => 'Bases suplementarias xa consultables-interrogables:',
'config_info_enregistree' => 'A nova configuraci&oacute;n foi gardada',
'config_info_logos' => 'Cada elemento do web pode ter un logo, as&iacute; como un &laquo;&nbsp;logo de substitucion&nbsp;&raquo;',
'config_info_logos_utiliser' => 'Utilizar os logos',
'config_info_logos_utiliser_non' => 'Non utilizar os logos',
'config_info_logos_utiliser_survol' => 'Utilizar os logos de substituci&oacute;n',
'config_info_logos_utiliser_survol_non' => 'Utilizar os logos de substituci&oacute;n',
'config_info_redirection' => 'En activando esta opci&oacute;n, poder&aacute; crear artigos virtuais, simples referencias de artigos publicados noutros web ou f&oacute;ra de SPIP.',
'config_redirection' => 'Artigos virtuais',
'config_titre_base_sup' => 'Declaraci&oacute;n dunha base suplementaria',
'config_titre_base_sup_choix' => 'Escolla unha base de datos suplementaria',
'connexion_ldap' => 'Conexi&amp;oacute;n :',
'copier_en_local' => 'Copiar en local',

// D
'date_mot_heures' => 'horas',
'diff_para_ajoute' => 'Par&aacute;grafo engadido',
'diff_para_deplace' => 'Par&aacute;grafo desprazado',
'diff_para_supprime' => 'Par&aacute;grafo suprimido',
'diff_texte_ajoute' => 'Texto engadido',
'diff_texte_deplace' => 'Texto desprazado',
'diff_texte_supprime' => 'Texto suprimido',
'double_clic_inserer_doc' => 'Faga dobre click para inserir este recurso no texto',

// E
'email' => 'correo electr&oacute;nico',
'email_2' => 'correo electr&oacute;nico:',
'en_savoir_plus' => 'M&aacute;is informaci&oacute;n',
'entree_adresse_annuaire' => 'Enderezo da gu&iacute;a',
'entree_adresse_email' => 'O seu enderezo de correo-e',
'entree_adresse_fichier_syndication' => 'Enderezo do ficheiro de afiliaci&oacute;n&nbsp;:',
'entree_adresse_site' => '<b>Enderezo do web</b> [Obrigatorio]',
'entree_base_donnee_1' => 'Enderezo da base de datos',
'entree_base_donnee_2' => '(Moitas veces este enderezo corresponde ao do teu web, &aacute;s veces corresp&oacute;ndese coa menci&oacute;n &laquo;localhost&raquo;, e outras p&oacute;dese deixar baleiro.)',
'entree_biographie' => 'Curta biograf&iacute;a en catro verbas.',
'entree_breve_publiee' => 'Quere que se publique a breve?',
'entree_chemin_acces' => '<b>Introduce</b> o cami&amp;ntilde;o de acceso&nbsp;:',
'entree_cle_pgp' => 'A t&uacute;a chave GPG',
'entree_contenu_rubrique' => '(Contido do tema en poucas palabras.)',
'entree_description_site' => 'Descrici&oacute;n do web',
'entree_identifiants_connexion' => 'O seu identificador de conexi&oacute;n...',
'entree_informations_connexion_ldap' => 'Escriba neste formulario os datos de conexi&oacute;n &aacute; t&uacute;a gu&iacute;a LDAP.
  Estes datos p&oacute;dellos facilitar o grupo de xesti&oacute;n do sistema, ou da rede.',
'entree_infos_perso' => 'Quen &eacute;?',
'entree_interieur_rubrique' => 'Dentro do tema:',
'entree_liens_sites' => '<b>Ligaz&oacute;n de hipertexto</b> (referencia, web para visitar...)',
'entree_login' => 'O seu identificador',
'entree_login_connexion_1' => 'O identificador de conexi&oacute;n',
'entree_login_connexion_2' => '(&aacute;s veces &eacute; o mesmo login que ten para o acceso por FTP; outras veces p&oacute;dese deixar baleiro)',
'entree_login_ldap' => 'Identificador LDAP inicial',
'entree_mot_passe' => 'A s&uacute;a chave',
'entree_mot_passe_1' => 'A chave da conexi&oacute;n',
'entree_mot_passe_2' => '(&aacute;s veces &eacute; o mesmo que ten para o acceso por FTP; outras veces p&oacute;dese deixar baleiro)',
'entree_nom_fichier' => 'Escrebe o nome do ficheiro @texte_compresse@:',
'entree_nom_pseudo' => 'O seu nome ou a s&uacute;a identidade (alcume)',
'entree_nom_pseudo_1' => '(O seu nome ou a s&uacute;a identidade, alcume)',
'entree_nom_site' => 'O nome do teu web',
'entree_nouveau_passe' => 'Nova chave',
'entree_passe_ldap' => 'Chave',
'entree_port_annuaire' => 'O n&uacute;mero de porto da gu&iacute;a',
'entree_signature' => 'Sinatura',
'entree_texte_breve' => 'Texto da breve',
'entree_titre_obligatoire' => '<b>T&amp;iacute;tulo</b> [Obrigado]<br />',
'entree_url' => 'O enderezo (URL) do teu web',
'erreur_plugin_desinstalation_echouee' => 'A desinstalaci&oacute;n do m&oacute;dulo fallou. No entanto, pode desactivalo.',
'erreur_plugin_fichier_absent' => 'Ficheiro ausente',
'erreur_plugin_fichier_def_absent' => 'Ficheiro de definici&oacute;n ausente',
'erreur_plugin_nom_fonction_interdit' => 'Nome de funci&oacute;n prohibido',
'erreur_plugin_nom_manquant' => 'Falta o nome do m&oacute;dulo',
'erreur_plugin_prefix_manquant' => 'Espazo de chamada do m&oacute;dulo non definido',
'erreur_plugin_tag_plugin_absent' => 'Falta o&lt;m&oacute;dulo&gt; no ficheiro de definici&oacute;n',
'erreur_plugin_version_manquant' => 'Falta a versi&oacute;n do m&oacute;dulo',

// F
'forum_info_original' => 'orixinal',

// H
'htaccess_a_simuler' => 'Aviso: a configuraci&oacute;n do seu servidor HTTP non ten conta dos ficheiros @htaccess@. Para poder asegurar unha boa seguridade, c&oacute;mpre que vostede modifique a configuraci&oacute;n neste aspecto, ou ben que as constantes @constantes@ (definibles no ficheiro mes_options.php) te&ntilde;an como valor  cartafoles f&oacute;ra de @document_root@.',
'htaccess_inoperant' => 'o htaccess non funciona',

// I
'ical_info1' => 'Esta p&aacute;xina presenta varios m&eacute;todos para establecer contactos coas novidades deste web.',
'ical_info2' => 'Para obter m&aacute;is detalles sobre todas estas t&eacute;cnicas, non dubide en consultar <a href="@spipnet@">a documentaci&oacute;n de SPIP</a>.',
'ical_info_calendrier' => 'Dous calendarios est&aacute;n &aacute; s&uacute;a disposici&oacute;n. O primeiro e un mapa do web que anuncia todos os artigos publicados. O segundo cont&eacute;n os anuncios editoriais as&iacute; como as s&uacute;as &uacute;ltimas mensaxes privadas&nbsp;: estalle reservada gracias a unha chave persoal, que pode modificar en calquera momento anovando a s&uacute;a chave.',
'ical_lien_rss_breves' => 'Afiliaci&oacute;n das breves do web',
'ical_methode_http' => 'Descarga',
'ical_methode_webcal' => 'Sincronizaci&oacute;n (webcal://)',
'ical_texte_js' => 'Unha li&ntilde;a de javascript perm&iacute;telle mostrar moi doadamente, sobre calquera web do que dispo&ntilde;a os artigos recentes deste web.',
'ical_texte_prive' => 'Este calendario, de uso estrictamente persoal, perm&iacute;telle informarse da actividade editorial privada deste web (tarefas e citas persoais, artigos e breves propostas...).',
'ical_texte_public' => 'Este calendario perm&iacute;telle seguir a actividade p&uacute;blica deste web (artigos e breves publicadas).',
'ical_texte_rss' => 'Pode sindicar as novidades deste web dentro de calquera lector de ficheiros en formato XML/RSS (Rich Site Summary). Este formato tam&eacute;n lle permite ler con SPIP as novidades publicadas noutros webs que utilicen un formato de intercambio compatible (webs sindicados).',
'ical_titre_js' => 'Javascript',
'ical_titre_mailing' => 'Lista de correo',
'ical_titre_rss' => 'Ficheiros de afiliaci&oacute;n',
'icone_activer_cookie' => 'Activar a cookie de correspondencia',
'icone_admin_plugin' => 'Xesti&oacute;n de m&oacute;dulos',
'icone_afficher_auteurs' => 'Mostrar o equipo de redacci&oacute;n',
'icone_afficher_visiteurs' => 'Mostrar as visitas',
'icone_arret_discussion' => 'Non volver participar nesta discusi&oacute;n',
'icone_calendrier' => 'Calendario',
'icone_creation_groupe_mots' => 'Crear un novo grupo de palabras',
'icone_creation_mots_cles' => 'Crear unha nova palabra chave',
'icone_creer_auteur' => 'Crear un novo membro do equipo de redacci&oacute;n e asocialo con este artigo',
'icone_creer_mot_cle' => 'Crear unha nova palabra chave e asociala con este artigo',
'icone_creer_mot_cle_breve' => 'Crear un nova palabra chave e ligala a esta breve',
'icone_creer_mot_cle_rubrique' => 'Crear unha nova palabra chave e ligala a esta secci&oacute;n',
'icone_creer_mot_cle_site' => 'Crear unha nova palabra chave e ligala a este web',
'icone_creer_rubrique_2' => 'Crear un novo tema',
'icone_ecrire_nouvel_article' => 'As breves contidas neste tema',
'icone_envoyer_message' => 'Enviar a mensaxe',
'icone_evolution_visites' => 'Evoluci&amp;oacute;n das visitas<br />@visites@ visitas',
'icone_modif_groupe_mots' => 'Modificar este grupo de palabras',
'icone_modifier_article' => 'Modificar este artigo',
'icone_modifier_breve' => 'Modificar esta breve',
'icone_modifier_message' => 'Modificar esta mensaxe',
'icone_modifier_mot' => 'Modificar esta palabra clave',
'icone_modifier_rubrique' => 'Modificar este tema',
'icone_modifier_site' => 'Modificar este web',
'icone_poster_message' => 'Enviar unha mensaxe',
'icone_publier_breve' => 'Publica esta breve',
'icone_referencer_nouveau_site' => 'Referencia dun novo web',
'icone_refuser_breve' => 'Rexeitar esta breve',
'icone_relancer_signataire' => 'Relanzar o signatario',
'icone_retour' => 'Volver',
'icone_retour_article' => 'Volver ao artigo',
'icone_suivi_forum' => 'Seguimento do foro p&uacute;blico: @nb_forums@ contribuci&oacute;n(s)',
'icone_supprimer_cookie' => 'Borrar a cookie de correspondencia',
'icone_supprimer_groupe_mots' => 'Borrar este grupo',
'icone_supprimer_rubrique' => 'Borrar este tema',
'icone_supprimer_signature' => 'Borrar esta sinatura',
'icone_valider_signature' => 'Validar a sinatura',
'icone_voir_sites_references' => 'Ver os webs referidos',
'icone_voir_tous_mots_cles' => 'Ver todas as palabras chave',
'image_administrer_rubrique' => 'Podes administrar este tema',
'info_1_article' => '1 artigo',
'info_1_breve' => '1 breve',
'info_1_site' => '1 web',
'info_activer_cookie' => 'Pode activar unha <b>cookie de correspondencia</b>, co cal poder&aacute; pasar facilmente do web p&uacute;blico ao web privado.',
'info_activer_forum_public' => '<i>Para activar os foros p&amp;uacute;blicos, escolla o xeito
  de moderaci&amp;oacute;n predeterminado:</i>',
'info_admin_gere_rubriques' => 'Esta persoa xestiona os seguintes temas:',
'info_admin_gere_toutes_rubriques' => 'Esta persoa xestiona <b>todos os temas</b>.',
'info_admin_statuer_webmestre' => 'Dar a este administrador dereitos de webm&aacute;ster',
'info_admin_webmestre' => 'Este administrdor &eacute; <b>webm&aacute;ster</b>',
'info_administrateur' => 'Xesti&oacute;n',
'info_administrateur_1' => 'Xesti&oacute;n',
'info_administrateur_2' => 'do web (<i>&uacute;sese con sentidi&ntilde;o</i>)',
'info_administrateur_site_01' => 'Se pertences &oacute; equipo de xesti&oacute;n,',
'info_administrateur_site_02' => 'preme nesta ligaz&oacute;n',
'info_administrateurs' => 'Xesti&oacute;n',
'info_administrer_rubrique' => 'Podes administrar este tema',
'info_adresse' => '&oacute; enderezo:',
'info_adresse_email' => 'ENDEREZO DE CORREO-E.:',
'info_adresse_url' => 'Enderezo (URL) do web p&uacute;blico',
'info_afficher_visites' => 'Mostrar as visitas de&nbsp;:',
'info_affichier_visites_articles_plus_visites' => 'Mostrar as visitas de <b>os artigos m&aacute;is visitados dende o principio:</b>',
'info_aide_en_ligne' => 'Axuda en li&ntilde;a do SPIP',
'info_ajout_image' => 'Cando engada imaxes como documentos adxuntos a un artigo,
  SPIP pode crear, automaticamente, vi&ntilde;etas (miniaturas) das
  imaxes insertas. Esto permite crear automaticamente
  unha galer&iacute;a de imaxes.',
'info_ajout_participant' => '@ O/A participante foi engadido:',
'info_ajouter_rubrique' => 'Engadir outro tema &aacute; administrar:',
'info_annonce_nouveautes' => 'Anuncio de novidades',
'info_anterieur' => 'Anterior',
'info_appliquer_choix_moderation' => 'Aplicar esta opci&oacute;n de moderaci&oacute;n:',
'info_article' => 'Artigo',
'info_article_2' => 'Artigos',
'info_article_a_paraitre' => 'Os artigos con data posterior &aacute; da sua publicaci&oacute;n',
'info_articles_02' => 'Artigos',
'info_articles_2' => 'Artigos',
'info_articles_auteur' => 'Os artigos desta persoa',
'info_articles_lies_mot' => 'Os artigos ligados a esta palabra chave',
'info_articles_trouves' => 'Artigos atopados',
'info_articles_trouves_dans_texte' => 'Artigos atopados (no texto)',
'info_attente_validation' => 'Os teus artigos en espera de validaci&oacute;n',
'info_aujourdhui' => 'hoxe:',
'info_auteur_message' => 'AUTOR/A DA MENSAXE:',
'info_auteurs' => 'O equipo de redacci&oacute;n',
'info_auteurs_par_tri' => 'Autores @partri@',
'info_auteurs_trouves' => 'Autores/as atopados',
'info_authentification_externe' => 'Autentificaci&oacute;n externa',
'info_avertissement' => 'Aviso',
'info_barre_outils' => 'coa barra de utilidades?',
'info_base_installee' => 'A estrutura da base de datos foi instalada.',
'info_base_restauration' => 'A base est&aacute; en proceso de restauraci&oacute;n.',
'info_bloquer' => 'bloquear',
'info_breves' => 'O seu web empregar&aacute; o sistema de breves?',
'info_breves_03' => 'breves',
'info_breves_liees_mot' => 'As breves ligadas a esta palabra chave',
'info_breves_touvees' => 'Breves atopadas',
'info_breves_touvees_dans_texte' => 'Breves atopadas (no texto)',
'info_changer_nom_groupe' => 'Trocar o nome deste grupo:',
'info_chapeau' => 'Cabeceira',
'info_chapeau_2' => 'Cabeceira:',
'info_chemin_acces_1' => 'Opci&amp;oacute;ns: <b>Cami&amp;ntilde;o de acceso ao anuario</b>',
'info_chemin_acces_2' => 'En adiante, ter&aacute; que configurar a v&iacute;a de acceso &aacute;s informaci&oacute;ns na gu&iacute;a. Esta informaci&oacute;n &eacute; indispensable para ler os perf&iacute;s de redactores gardados na gu&iacute;a.',
'info_chemin_acces_annuaire' => 'Opci&amp;oacute;ns: <b>Cami&amp;ntilde;o de acceso ao anuario</b>',
'info_choix_base' => 'Terceira etapa:',
'info_classement_1' => '<sup>o</sup> en @liste@',
'info_classement_2' => '<sup>a</sup> en @liste@',
'info_code_acces' => 'Non esquezas os teus c&oacute;digos de acceso!',
'info_comment_lire_tableau' => 'C&oacute;mo interpretar este cadro',
'info_compresseur_gzip' => '<b>N.&nbsp;B.&nbsp;:</b> Recom&eacute;ndaselle comprobar antes de nada se o aloxador comprime xa sistematicamente os  scripts php&nbsp;; para iso, pode utilizar por exemplo o servizo seguinte&nbsp;: @testgzip@',
'info_compresseur_texte' => 'No caso de que o seu servidor non comprima automaticamente as p&aacute;xinas html para enviarllas aos internautas, pode probar a forzar esta compresi&oacute;n para diminu&iacute;r o peso das p&aacute;xinas para descarga. <b>Alerta</b> : isto pode ralentizar considerablemente certos servidores.',
'info_compresseur_titre' => 'Optimizaci&oacute;n e compresi&oacute;n',
'info_config_forums_prive' => 'No espazo privado do web, pode activar varios tipos de foros&nbsp;:',
'info_config_forums_prive_admin' => 'Un foro reservado aos administradores do web&nbsp;:',
'info_config_forums_prive_global' => 'Un foro global, aberto a todos os redactores&nbsp;:',
'info_config_forums_prive_objets' => 'Un foro sobre cada artigo, breve, web referido, etc.&nbsp;:',
'info_config_suivi' => 'Se este enderezo corresponde &aacute; unha lista de correo, vostede pode indicar aqu&iacute; abaixo o enderezo co cal os participantes no web se poden inscribir. Este enderezo pode ser un URL (por exemplo a p&aacute;xina de inscrici&oacute;n &aacute; lista via web), ou un enderezo de correo electr&oacute;nico dotado dun asunto espec&iacute;fico (por exemplo: <tt>@adresse_suivi@?subject=subscribirse</tt>):',
'info_config_suivi_explication' => 'Pode subscribirse &aacute; lista de correo deste web. Recibir&aacute; ent&oacute;n por correo os anuncios de artigos e de breves propostas para publicaci&oacute;n.',
'info_confirmer_passe' => 'Confirmar a nova chave:',
'info_conflit_edition_avis_non_sauvegarde' => 'Aviso, os campos seguintes foron modificados por outros. As s&uacute;as modificaci&oacute;ns nestes campos non foron rexistradas.',
'info_conflit_edition_differences' => 'Diferenzas&nbsp;:',
'info_conflit_edition_version_enregistree' => 'A versi&oacute;n rexistrada&nbsp;:',
'info_conflit_edition_votre_version' => 'A s&uacute;a versi&oacute;n&nbsp;:',
'info_connexion_base' => 'Proba de conexi&oacute;n coa base de datos',
'info_connexion_base_donnee' => 'Conexi&oacute;n &aacute;s s&uacute;a base de datos',
'info_connexion_ldap_ok' => 'Conseguiu conexi&oacute;n LDAP.</b><p> Pode pasar &aacute; etapa seguinte.</p>',
'info_connexion_mysql' => 'A s&uacute;a conexi&oacute;n SQL',
'info_connexion_ok' => 'Conexi&oacute;n feita.',
'info_contact' => 'Contacto',
'info_contenu_articles' => 'Contido dos artigos',
'info_creation_mots_cles' => 'Crea e configura aqu&iacute; as palabras chave do web',
'info_creation_paragraphe' => '(Para crear par&aacute;grafos, simplemente deixe li&ntilde;as baleiras.)',
'info_creation_rubrique' => 'Antes de poder escribir artigos,<br /> ten que crear, cando menos un tema ou secci&amp;oacute;n.<br />',
'info_creation_tables' => 'Creaci&oacute;n das t&aacute;boas da base de datos',
'info_creer_base' => '<b>Crear</b> unha nova base de datos:',
'info_dans_groupe' => 'No grupo:',
'info_dans_rubrique' => 'No tema:',
'info_date_publication_anterieure' => 'Data de redacci&oacute;n anterior:',
'info_date_referencement' => 'DATA DE REFERENCIA DESTE WEB:',
'info_delet_mots_cles' => 'Solicitouse eliminar a palabra clave
<b>@titre_mot@</b> (@type_mot@). Esta palabra clave est&amp;aacute; ligada a
<b>@texte_lie@</b>, ten que confirmar a s&amp;uacute;a decisi&amp;oacute;n&nbsp;:',
'info_derniere_etape' => 'Acabouse!',
'info_derniere_syndication' => 'A &uacute;ltima afiliaci&oacute;n deste web f&iacute;xose o',
'info_derniers_articles_publies' => 'Os teus &uacute;ltimos artigos publicados en li&ntilde;a',
'info_desactiver_forum_public' => 'Desactivar o uso dos foros
  p&uacute;blicos. Os foros p&uacute;blicos poder&aacute;n ser autorizados caso por caso
  nos artigos; ser&aacute;n prohibidos nos temas, nas breves, etc.',
'info_desactiver_messagerie_personnelle' => 'Pode activar ou desactivar a s&uacute;a mensaxer&iacute;a persoal neste web.',
'info_descriptif' => 'Descrici&oacute;n:',
'info_desinstaller_plugin' => 'elimina os datos e desactiva o plugin',
'info_discussion_cours' => 'Discusi&oacute;ns en proceso',
'info_ecrire_article' => 'Antes de poder escribir artigos, tes que crear, cando menos un tema ou secci&oacute;n.',
'info_email_envoi' => 'Enderezo de env&iacute;o de correo (opcional)',
'info_email_envoi_txt' => 'Indique aqu&iacute; o enderezo para lle enviar os correos (por defecto o enderezo destinatario ser&aacute; usado como enderezo de env&iacute;o)&nbsp;:',
'info_email_webmestre' => 'Enderezo de correo-e. do/a webm&aacute;ster (opcional)',
'info_entrer_code_alphabet' => 'Teclea o c&oacute;digo do alfabeto a empregar:',
'info_envoi_email_automatique' => 'Env&iacute;o autom&aacute;tico de correos-e.',
'info_envoi_forum' => 'Env&iacute;o de foros &aacute;s/&oacute;s autoras/es dos artigos',
'info_envoyer_maintenant' => 'Enviar agora',
'info_erreur_restauration' => 'Erro de restauraci&oacute;n: o ficheiro non existe.',
'info_etape_suivante' => 'Pasar &aacute; etapa seguinte',
'info_etape_suivante_1' => 'Podes pasar &aacute; etapa seguinte.',
'info_etape_suivante_2' => 'Podes pasar &aacute; etapa seguinte.',
'info_exportation_base' => 'exportaci&oacute;n da base cara a @archive@',
'info_facilite_suivi_activite' => 'Para facilitar o seguimento da actividade
  editorial do web, SPIP pode enviar por correo-e., por exemplo
  a unha lista de enderezos do equipo de redacci&oacute;n, avisos das petici&oacute;ns
  de publicaci&oacute;n e de validaci&oacute;ns dos artigos.',
'info_fichiers_authent' => 'Ficheiros de autenticaci&oacute;n &laquo;.htpasswd&raquo;',
'info_fonctionnement_forum' => 'Funcionamento do foro:',
'info_forum_administrateur' => 'foro do equipo de xesti&oacute;n',
'info_forum_interne' => 'foro interno',
'info_forum_ouvert' => 'Dentro do espazo privado do web, hai un foro aberto
  a toda os usuarios rexistrados. Aqu&iacute; abaixo pode activar un foro
  complementar, reservado ao equipo de xesti&oacute;n.',
'info_forum_statistiques' => 'Estat&iacute;sticas das visitas',
'info_forums_abo_invites' => 'O seu web disp&oacute;n de foros para se aboar&nbsp;; os visitantes est&aacute;n invitados a se rexistrar neles na parte p&uacute;blica do web.',
'info_gauche_admin_effacer' => '<b>Esta p&aacute;xina &eacute; unicamente accessible para o equipo de xesti&oacute;n do web.</b><p> D&aacute;lle acceso a diferentes funci&oacute;ns de mantemento t&eacute;cnico. Algunhas delas dan lugar a procesos de autenticaci&oacute;n espec&iacute;ficos, que esixen ter un acceso por FTP ao web.</p>',
'info_gauche_admin_tech' => '<b>Esta p&aacute;xina &eacute; unicamente accessible para o equipo de xesti&oacute;n do web.</b><p> D&aacute;lle acceso a diferentes funci&oacute;ns de mantemento t&eacute;cnico. Algunhas delas dan lugar a procesos de autenticaci&oacute;n espec&iacute;ficos, que esixen ter un acceso por FTP ao web.</p>',
'info_gauche_admin_vider' => '<b>Esta p&aacute;xina &eacute; unicamente accesible para o equipo de xesti&oacute;n do web.</b><p> D&aacute;lle acceso a diferentes funci&oacute;ns de mantemento t&eacute;cnico. Algunhas delas dan lugar a procesos de autenticaci&oacute;n espec&iacute;ficos, que esixeb ter un acceso por FTP ao web.</p>',
'info_gauche_auteurs' => 'Aqu&iacute; atopar&aacute;s a todos os autores do web.
  O seu status ind&iacute;case coa cor da s&uacute;a &iacute;cona (xestor = verde; redactor = amarela).',
'info_gauche_auteurs_exterieurs' => 'Os colaboradores exteriores, sen acceso ao web, ind&iacute;canse por unha &iacute;cona azul;
  os autores que foron eliminados, por unha papeleira.',
'info_gauche_messagerie' => 'A mensaxer&iacute;a perm&iacute;teche intercambiar mensaxes entre o equipo de redacci&oacute;n, gardar notas (para o teu uso persoal) ou mostrar os anuncios na p&aacute;xina de entrada do espazo privado (se est&aacute;s no equipo de xesti&oacute;n).',
'info_gauche_numero_auteur' => 'AUTOR/A N&Uacute;MERO',
'info_gauche_numero_breve' => 'BREVE N&Uacute;MERO',
'info_gauche_statistiques_referers' => 'Esta p&aacute;xina presenta a lista de <i>referentes</i>,
  ou sexa, os enderezos con ligaz&oacute;ns apuntando a este mesmo web, &uacute;nicamente para onte e para hoxe; esta lista ponse a cero a cada 24 horas.',
'info_gauche_suivi_forum' => 'A p&amp;aacute;xina de <i>seguimento dos foros</i> &amp;eeacute; unha ferramenta de xesti&amp;oacute;n do web (e non un espazo de discusi&amp;oacute;n ou de redacci&amp;oacute;n). Mostra todas as contribuci&amp;oacute;ns no foro p&amp;uacute;blico deste artigo e permite xestionar estas contribuci&amp;oacute;ns.',
'info_gauche_suivi_forum_2' => 'A p&amp;acute;xina de <i>seguimento dos foros</i>  &amp;eeacute; unha ferramenta de xesti&amp;oacute;n do web (e non un espazo de discusi&amp;oacute;n ou de redacci&amp;oacute;n). Mostra todas as contribuci&amp;oacute;ns nos foros do web, tanto as do espazo p&amp;uacute;blico coma as do espazo privado e permite xestionar estas contribuci&amp;oacute;ns.',
'info_gauche_visiteurs_enregistres' => 'aqu&iacute; atopar&aacute;s as visitas rexistradas
  no espazo p&uacute;blico do web (foros con rexistro).',
'info_generation_miniatures_images' => 'Creaci&oacute;n de miniaturas das imaxes',
'info_gerer_trad' => 'Crear as ligaz&oacute;ns de traduci&oacute;n ?',
'info_groupe_important' => 'Grupo importante',
'info_hebergeur_desactiver_envoi_email' => 'Alg&uacute;ns aloxadores desactivan o env&iacute;o autom&aacute;tico de
  correos-e. dende os seus servidores. Nese caso, as seguintes funcionalidades do
  SPIP non estar&aacute;n dispo&ntilde;ibles.',
'info_hier' => 'onte:',
'info_historique' => 'Revisi&oacute;ns&nbsp;:',
'info_historique_activer' => 'Activar o seguimento de revisi&oacute;ns',
'info_historique_affiche' => 'Mostrar esta versi&oacute;n',
'info_historique_comparaison' => 'Comparaci&oacute;n',
'info_historique_desactiver' => 'Desactivar o seguimento de revisi&oacute;ns',
'info_historique_lien' => 'Mostrar o hist&oacute;rico de modificaci&oacute;ns',
'info_historique_texte' => 'O seguimento de revisi&oacute;ns permite conservar un hist&oacute;rico de todas as modificaci&oacute;ns realizadas no contido dun artigo, e de mostrar as diferenzas entre as versi&oacute;ns sucesivas.',
'info_historique_titre' => 'Seguimento de revisi&oacute;ns',
'info_identification_publique' => 'A s&uacute;a identidade p&uacute;blica...',
'info_image_process' => 'Probe a seleccionar o mellor m&eacute;todo de fabricaci&oacute;n de vi&ntilde;etas premendo sobre a imaxe correspondente.',
'info_image_process2' => '<b>N.B.</b> <i>Se non aparece ningunha imaxe, significa que o servidor que aloxa o web non foi configurado para para usar tales utilidades. Se desexa empregar estas funci&oacute;ns, contacte co responsable t&eacute;cnico e solic&iacute;telle as extensi&oacute;ns &laquo;GD&raquo; ou &laquo;Imagick&raquo;.</i>',
'info_images_auto' => 'Imaxes calculadas automaticamente',
'info_informations_personnelles' => 'Datos persoais',
'info_inscription_automatique' => 'Rexistro autom&aacute;tico de novos redactores',
'info_jeu_caractere' => 'Xogo de caracteres do web',
'info_jours' => 'd&iacute;as',
'info_laisser_champs_vides' => 'deixar estes campos baleiros)',
'info_langues' => 'Idiomas do web',
'info_ldap_ok' => 'A autentificaci&oacute;n LDAP foi instalada.',
'info_lien_hypertexte' => 'Ligaz&oacute;n de hipertexto:',
'info_liens_syndiques_1' => 'ligaz&oacute;n afiliada',
'info_liens_syndiques_2' => 'est&aacute;n agardando pola validaci&oacute;n.',
'info_liens_syndiques_3' => 'foros',
'info_liens_syndiques_4' => 'est&aacute;n',
'info_liens_syndiques_5' => 'foro',
'info_liens_syndiques_6' => 'est&aacute;',
'info_liens_syndiques_7' => 'agardando pola validaci&oacute;n',
'info_liste_redacteurs_connectes' => 'Lista de redactores conectados',
'info_login_existant' => 'Este identificador xa existe.',
'info_login_trop_court' => 'Identificador curto de m&aacute;is.',
'info_logos' => 'Os logos',
'info_maximum' => 'm&aacute;ximo:',
'info_meme_rubrique' => 'Na mesma r&uacute;brica ou secci&oacute;n',
'info_message' => 'Mensaxe de',
'info_message_efface' => 'MENSAXE BORRADA',
'info_message_en_redaction' => 'As t&uacute;as mensaxes en proceso de redacci&oacute;n',
'info_message_technique' => 'Mensaxe t&eacute;cnica:',
'info_messagerie_interne' => 'mensaxer&iacute;a interna',
'info_mise_a_niveau_base' => 'posta ao d&iacute;a da s&uacute;a base SQL',
'info_mise_a_niveau_base_2' => '{{Atenci&oacute;n!}} Instalou unha versi&amp;oacute;n
  de ficheiros SPIP {anterior} &amp;aacute; que ti&ntilde;a instalada
  antes neste web: a s&amp;uacute;a base de datos pode que se perdese
  e o seu web xa non funcionar&amp;oacute;.<br />{{Reinstale os
  ficheiros de SPIP.}}',
'info_mode_fonctionnement_defaut_forum_public' => 'Configuraci&oacute;n por defecto dos foros p&uacute;blicos',
'info_modifier_auteur' => 'Modificar o autor:',
'info_modifier_breve' => 'Modificar a breve:',
'info_modifier_mot' => 'Modificar a palabra clave :',
'info_modifier_rubrique' => 'Modificar o tema:',
'info_modifier_titre' => 'Modificar: @titre@',
'info_mon_site_spip' => 'O meu web SPIP',
'info_mot_sans_groupe' => '(Palabra sen grupo...)',
'info_moteur_recherche' => 'Motor de procura integrado',
'info_mots_cles' => 'As palabras chave',
'info_mots_cles_association' => 'As palabras chave deste grupo poden estar aociadas:',
'info_moyenne' => 'mediana:',
'info_multi_articles' => 'Activar o men&uacute; de lingua sobre os artigos&nbsp;?',
'info_multi_cet_article' => 'Lingua deste artigo&nbsp;:',
'info_multi_langues_choisies' => 'Quere seleccionar despois as linguas dispo&ntilde;ibles dos redactores de seu web.
  As linguas xa utilizadas no seu web (fixadas ao principio) non poden ser desactivadas.',
'info_multi_rubriques' => 'Activar o men&uacute; de lingua nas secci&oacute;ns&nbsp;?',
'info_multi_secteurs' => '... soamente para as secci&oacute;ns situadas na ra&iacute;z&nbsp;?',
'info_nom' => 'Nome',
'info_nom_destinataire' => 'Nome do/a destinatario',
'info_nom_site' => 'Nome do seu web',
'info_nom_site_2' => '<b>Nome do web</b>[Obrigatorio]',
'info_nombre_articles' => '@nb_articles@ artigos,',
'info_nombre_breves' => '@nb_breves@ breves,',
'info_nombre_partcipants' => 'PARTICIPANTES NA DISCUSI&Oacute;N:',
'info_nombre_rubriques' => '@nb_rubriques@ temas,',
'info_nombre_sites' => '@nb_sites@ webs,',
'info_non_deplacer' => 'Non desplazar...',
'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pode enviar, regularmente, o anuncio das
  &uacute;ltimas novidades do web (artigos e breves recentes).',
'info_non_envoi_liste_nouveautes' => 'Non enviar &aacute; lista de novidades',
'info_non_modifiable' => 'Non se pode modificar',
'info_non_suppression_mot_cle' => 'Non quero eliminar esta palabra chave.',
'info_notes' => 'Notas',
'info_nouveaux_message' => 'Novas mensaxes',
'info_nouvel_article' => 'Novo artigo',
'info_nouvelle_traduction' => 'Nova traduci&oacute;n&nbsp;:',
'info_numero_article' => 'ARTIGO N&Uacute;MERO:',
'info_obligatoire_02' => '[Obrigatorio]',
'info_option_accepter_visiteurs' => 'Aceptar a inscrici&oacute;n de visitantes do web p&uacute;blico',
'info_option_email' => 'Cando unha visita env&iacute;a unha nova mensaxe no foro
  vencellado a un artigo, os autores relacionados co artigo poden recibir
  aviso desta mensaxe por correo-e. Quere preguntar para cada tipo de foro se c&oacute;mpre empregar esta opci&oacute;n?',
'info_option_faire_suivre' => 'Enviar aviso das mensaxes dos foros &aacute;s persoas responsabeis dos artigos',
'info_option_ne_pas_accepter_visiteurs' => 'Rexeitar a inscrici&oacute;n de visitantes',
'info_option_ne_pas_faire_suivre' => 'Non enviar avisos das mensaxes dos foros',
'info_options_avancees' => 'OPCI&Oacute;NS AVANZADAS',
'info_ortho_activer' => 'Activar a comprobaci&oacute;n de ortograf&iacute;a.',
'info_ortho_desactiver' => 'Desactivar a comprobaci&oacute;n de ortograf&iacute;a.',
'info_ou' => 'ou...',
'info_oui_suppression_mot_cle' => 'Quero suprimir definitivamente esta palabra chave.',
'info_page_interdite' => 'P&aacute;xina prohibida',
'info_par_nom' => 'por nome',
'info_par_nombre_article' => 'por n&uacute;mero de artigos',
'info_par_statut' => 'por estado',
'info_par_tri' => '\'(por @tri@)\'',
'info_pas_de_forum' => 'non hai foro',
'info_passe_trop_court' => 'Chave moi curta.',
'info_passes_identiques' => 'As d&uacute;as chaves non son id&eacute;nticas.',
'info_pense_bete_ancien' => 'Notas vellas', # MODIF
'info_plus_cinq_car' => 'm&aacute;is de 5 caracteres',
'info_plus_cinq_car_2' => '(M&aacute;is de 5 caracteres)',
'info_plus_trois_car' => '(M&aacute;is de 3 caracteres)',
'info_popularite' => 'popularidade: @popularite@; visitas: @visites@',
'info_popularite_2' => 'popularidade do web:',
'info_popularite_3' => 'popularidade: @popularite@; visitas: @visites@',
'info_popularite_4' => 'popularidade: @popularite@; visitas: @visites@',
'info_post_scriptum' => 'P&eacute; do artigo',
'info_post_scriptum_2' => 'P&eacute; do artigo:',
'info_pour' => 'para',
'info_preview_admin' => 'S&oacute; os administradores poden previsualizar o web',
'info_preview_comite' => 'Todos os redactores poden previsualizar o web',
'info_preview_desactive' => 'A previsualizaci&oacute;n est&aacute; totalmente desactivada',
'info_preview_texte' => '&Eacute; pos&iacute;bel previsualizar o web como se todos os artigos e breves (que te&ntilde;an cando menos o estado de &laquo;&nbsp;proposto&nbsp;&raquo;) estivesen publicados. Esta posibilidade debe estar aberta s&oacute; para os administradores, para todos os redactores, ou para calquera&nbsp;?',
'info_principaux_correspondants' => 'Os colaboradores principais',
'info_procedez_par_etape' => 'procede etapa por etapa',
'info_procedure_maj_version' => 'o procedemento da posta &oacute; d&iacute;a ten que ser lanzado a fin
		de adaptar a base de datos &aacute; nova versi&oacute;n de SPIP.',
'info_proxy_ok' => 'Test de proxy logrado.',
'info_ps' => 'PS.',
'info_publier' => 'publicar',
'info_publies' => 'Os teus artigos publicados en li&ntilde;a',
'info_question_accepter_visiteurs' => 'Se os esqueletos do seu web prev&eacute;n o rexistro de visitantes sen acceso &aacute; parte web privada, active a opci&oacute;n aqu&iacute; abaixo&nbsp;:',
'info_question_activer_compactage_css' => 'Quere activar a compactaci&oacute;n das follas de estilo(CSS) ?',
'info_question_activer_compactage_js' => 'Quere activar a compactaci&oacute;n de scripts (javascript) ?',
'info_question_activer_compresseur' => 'Quere activar a compactaci&oacute;n do fluxo  HTTP ?',
'info_question_gerer_statistiques' => 'O seu web ten que xerar as estat&iacute;sticas das visitas?',
'info_question_inscription_nouveaux_redacteurs' => 'Aceptar&aacute; as inscrici&oacute;ns de novos redactores
  desde o web p&uacute;blico? De aceptalos, os visitantes poderanse rexistrar cun
  formulario automatizado e acceder&aacute;n ao espazo privado para
  propor os seus propios artigos.<blockquote> <i>Trala fase de inscrici&oacute;n,
  os usuarios recibir&aacute;n un correo electr&oacute;nico autom&aacute;tico
  cos seus c&oacute;digos de acceso ao web privado. Alg&uacute;ns
  provedores desactivan o env&iacute;o autom&aacute;tico desde os seus servidores:
  nese caso, a inscrici&oacute;n autom&aacute;tica &eacute; imposible.</i></blockquote>',
'info_question_mots_cles' => 'Quere empregar as palabras chave neste seu web?',
'info_question_proposer_site' => 'Quen pode propor os webs referidos?',
'info_question_utilisation_moteur_recherche' => 'Quere empregar o motor de procura integrado en SPIP?
  (desactivalo acelera o funcionamento do sistema.)',
'info_question_vignettes_referer' => 'Cando vostede consulte as estat&iacute;sticas, pode visualizar resumos dos webs que orixinan as visitas.',
'info_question_vignettes_referer_non' => 'Non mostrar as capturas de webs de orixe das visitas',
'info_question_vignettes_referer_oui' => 'Mostrar as capturas de web de orixe das visitas',
'info_question_visiteur_ajout_document_forum' => 'Se quere autorizar os visitantes para que poidan anexar documentos (imaxes, sons...) nas s&uacute;as mensaxes dos foros, indique a seguir a lista de extensi&oacute;ns autorizadas para os foros (ex: gif, jpg, png, mp3).',
'info_question_visiteur_ajout_document_forum_format' => 'Se quere autorizar todos os tipos de documentos considerados como fiables por SPIP, marque unha estrela. Para non autorizar nada, non indique nada.',
'info_qui_attribue_mot_cle' => 'As palabras deste grupo poden ser atribuidas a:',
'info_racine_site' => 'Ra&iacute;z do web',
'info_recharger_page' => 'Recarga a p&aacute;xina nuns intres.',
'info_recherche_auteur_a_affiner' => 'Resultados de m&aacute;is para "@cherche_auteur@"; por favor, afine a s&uacute;a procura.',
'info_recherche_auteur_ok' => 'Atopou.se m&aacute;is dunha persoa para "@cherche_auteur@":',
'info_recherche_auteur_zero' => '<b>Ning&uacute;n resultado para "@cherche_auteur@".',
'info_recommencer' => 'Volta empezar.',
'info_redacteur_1' => 'Redactor/a',
'info_redacteur_2' => 'que te&ntilde;an acceso &oacute; espazo privado (<i>recomendado</i>)',
'info_redacteurs' => 'Redacci&oacute;n',
'info_redaction_en_cours' => 'EN PROCESO DE REDACCI&Oacute;N',
'info_redirection' => 'Redirecci&oacute;n',
'info_referencer_doc_distant' => 'Referenciar un documento na internet&nbsp;:',
'info_refuses' => 'Os teus artigos rexeitados',
'info_reglage_ldap' => 'Opci&amp;oacute;ns: <b>Axustes da importaci&amp;oacute;n LDAP</b>',
'info_renvoi_article' => '<b>Redirecci&amp;oacute;n.</b> Este artigo reenv&amp;iacute; &amp;aacute; p&amp;aacute;xina:',
'info_reserve_admin' => 'S&oacute; o equipo de xesti&oacute;n pode modificar este enderezo.',
'info_restauration_sauvegarde' => 'Restauraci&oacute;n da copia de seguridade @archive@',
'info_restauration_sauvegarde_insert' => 'Inserci&oacute;n de @archive@ na base de datos',
'info_restreindre_rubrique' => 'Restrinxir a xesti&oacute;n &oacute; tema:',
'info_resultat_recherche' => 'Resultados da procura:',
'info_rubriques' => 'temas',
'info_rubriques_02' => 'temas',
'info_rubriques_liees_mot' => 'Os temas ligados a esta palabra chave',
'info_rubriques_trouvees' => 'Temas atopados',
'info_rubriques_trouvees_dans_texte' => 'Temas atopados (no texto)',
'info_sans_titre' => 'Sen t&iacute;tulo',
'info_sauvegarde' => 'Copia de seguridade',
'info_sauvegarde_articles' => 'Gardar os artigos',
'info_sauvegarde_articles_sites_ref' => 'Gardar os artigos dos webs referidos',
'info_sauvegarde_auteurs' => 'Gardar os autores',
'info_sauvegarde_breves' => 'Gardar as breves',
'info_sauvegarde_documents' => 'Gardar os documentos',
'info_sauvegarde_echouee' => 'Se a copia de seguridade fallou (&laquo;Maximum execution time exceeded&raquo;),',
'info_sauvegarde_forums' => 'Gardar os foros',
'info_sauvegarde_groupe_mots' => 'Gardar os grupos de palabras',
'info_sauvegarde_messages' => 'Gardar as mensaxes',
'info_sauvegarde_mots_cles' => 'Gardar as palabras chave',
'info_sauvegarde_petitions' => 'Gardar as petici&oacute;ns',
'info_sauvegarde_refers' => 'Gardar os referentes',
'info_sauvegarde_reussi_01' => 'Feita a copia de seguridade.',
'info_sauvegarde_reussi_02' => 'A base foi gardada en @archive@. Pode ',
'info_sauvegarde_reussi_03' => 'volver &aacute; xesti&oacute;n',
'info_sauvegarde_reussi_04' => 'do seu web.',
'info_sauvegarde_rubrique_reussi' => 'As t&aacute;boas da secci&oacute;n @titre@ foron gardadas en @archive@. Pode',
'info_sauvegarde_rubriques' => 'Gardar os temas',
'info_sauvegarde_signatures' => 'Gardar as sinaturas de petici&oacute;ns',
'info_sauvegarde_sites_references' => 'Gardar os webs referidos',
'info_sauvegarde_type_documents' => 'Gardar os tipos de documentos',
'info_sauvegarde_visites' => 'Gardar as visitas',
'info_selection_chemin_acces' => '<b>Selecciona</b> aqu&iacute; a v&iacute;a de acceso &aacute; gu&iacute;a:',
'info_selection_un_seul_mot_cle' => 'Neste grupo p&oacute;dese seleccionar <b>s&oacute; unha palabra chave</b> ao mesmo tempo.',
'info_signatures' => 'sinaturas',
'info_site' => 'Web',
'info_site_2' => 'web:',
'info_site_min' => 'web',
'info_site_propose' => 'Web proposto o:',
'info_site_reference_2' => 'Web referido/referenciado',
'info_site_syndique' => 'Este web est&aacute; afiliado...',
'info_site_valider' => 'Webs por validar',
'info_site_web' => 'WEB:',
'info_sites' => 'sitios',
'info_sites_lies_mot' => 'Os webs referidos ligados a esta palabra chave',
'info_sites_proxy' => 'Empregar un proxy',
'info_sites_refuses' => 'Os webs rexeitados',
'info_sites_trouves' => 'Webs atopados',
'info_sites_trouves_dans_texte' => 'Webs atopados (no texto)',
'info_sous_titre' => 'Subt&iacute;tulo:',
'info_statut_administrateur' => 'Equipo de xesti&oacute;n',
'info_statut_auteur' => 'Categor&iacute;a deste autor:',
'info_statut_auteur_a_confirmer' => 'Inscrici&oacute;n para confirmar',
'info_statut_auteur_autre' => 'Outro estatuto&nbsp;:',
'info_statut_efface' => 'Eliminado',
'info_statut_redacteur' => 'Redactor/a',
'info_statut_site_1' => 'Este web foi:',
'info_statut_site_2' => 'Publicado',
'info_statut_site_3' => 'Proposto',
'info_statut_site_4' => 'No lixo',
'info_statut_utilisateurs_1' => 'Categor&iacute;a por defecto de redactores importados',
'info_statut_utilisateurs_2' => 'Escolla a categor&iacute;a que han ter as persoas presentes na gu&iacute;a LDAP cando se conecten por primeira vez. M&aacute;is tarde poder&aacute;s trocar este valor caso por caso.',
'info_suivi_activite' => 'Seguimento da actividade editorial',
'info_supprimer_mot' => 'suprimir esta palabra',
'info_surtitre' => 'Sobret&iacute;tulo:',
'info_syndication_integrale_1' => 'O seu web prop&oacute;n ficheiros de subscrici&oacute;n (ver &laquo;&nbsp;<a href="@url@">@titre@</a>&nbsp;&raquo;).',
'info_syndication_integrale_2' => 'Quere transmitir os seus artigos &iacute;ntegros, ou non difundir m&aacute;is ca un resumo dalg&uacute;ns centos de car&aacute;cteres&nbsp;?',
'info_table_prefix' => 'Pode modificarse o prefixo do nome das t&aacute;boas da base de datos (iso &eacute; imprescindible s&oacute; cando se quere instalar varios spip na mesma base de datos). Este prefixo debe escribirse unicamente con letras min&uacute;sculas e sen acentos nin espazos en branco.',
'info_taille_maximale_images' => 'SPIP testar&aacute; o tama&ntilde;o m&aacute;ximo das imaxes que pode tratar (en mill&oacute;ns de p&iacute;xels).<br /> As imaxes maiores non ser&aacute;n reducidas.',
'info_taille_maximale_vignette' => 'Tama&ntilde;o m&aacute;ximo das vi&ntilde;etas xeradas polo sistema:',
'info_terminer_installation' => 'Agora podes rematar o proceso de instalaci&oacute;n est&aacute;ndar.',
'info_texte' => 'Texto',
'info_texte_explicatif' => 'Texto explicativo',
'info_texte_long' => '(o texto &eacute; moi longo: as&iacute; pois, aparecer&aacute; en varias partes que ser&aacute;n recompostas trala validaci&oacute;n.)',
'info_texte_message' => 'Texto da s&uacute;a mensaxe:',
'info_texte_message_02' => 'Texto da mensaxe',
'info_titre' => 'T&iacute;tulo:',
'info_titre_mot_cle' => 'Nome ou t&iacute;tulo da palabra chave',
'info_total' => 'total:',
'info_tous_articles_en_redaction' => 'Todo os artigos en proceso de redacci&oacute;n',
'info_tous_articles_presents' => 'Todos os artigos publicados neste tema',
'info_tous_articles_refuses' => 'Todos os artigos foron rexeitados',
'info_tous_les' => 'todos os:',
'info_tous_redacteurs' => 'Anuncios a toda a redacci&oacute;n',
'info_tout_site' => 'Todo o web',
'info_tout_site2' => 'O artigo non foi traducido nesta lingua.',
'info_tout_site3' => 'O artigo foi traducido nesta lingua, pero as modificaci&oacute;ns foron aplicadas polo momento ao artigo de referencia. A traduci&oacute;n debe ser actualizada.',
'info_tout_site4' => 'O artigo foi traducido nesta lingua e a traduci&oacute;n est&aacute; actualizada.',
'info_tout_site5' => 'Artigo orixinal.',
'info_tout_site6' => '<b>Atenci&oacute;n&nbsp;:</b> s&oacute; os artigos orixinais son amosados.
As traduci&oacute;ns son asociadas ao orixinal,
cunha cor que indica o seu estado&nbsp;:',
'info_travail_colaboratif' => 'Traballo de colaboraci&oacute;n nos artigos',
'info_un_article' => 'un artigo,',
'info_un_mot' => 'Unha palabra a cada vez',
'info_un_site' => 'un web,',
'info_une_breve' => 'unha breve,',
'info_une_rubrique' => 'un tema,',
'info_une_rubrique_02' => '1 tema',
'info_url' => 'URL:',
'info_url_site' => 'URL DO WEB&nbsp;:',
'info_urlref' => 'Ligaz&oacute;n de hipertexto&nbsp;:',
'info_utilisation_spip' => 'Agora podes comezar a usar o sistema de publicaci&oacute;n asistida...',
'info_visites_par_mois' => 'Ordear por mes:',
'info_visites_plus_populaires' => 'Mostrar as visitas para <b>os artigos m&aacute;is populares</b> e para <b>os &uacute;ltimos artigos publicados:</b>',
'info_visiteur_1' => 'Visitante',
'info_visiteur_2' => 'do web p&uacute;blico',
'info_visiteurs' => 'Visitantes',
'info_visiteurs_02' => 'Visitantes do web p&uacute;blico',
'install_adresse_base_hebergeur' => 'Enderezo da base de datos atribu&iacute;da polo aloxador',
'install_base_ok' => 'A base @base@ foi reco&ntilde;ecida',
'install_echec_annonce' => 'A instalaci&oacute;n probabelmente vai pechar ou lanzar un sitio non funcional...',
'install_extension_mbstring' => 'SPIP non funnciona con&nbsp;:',
'install_extension_php_obligatoire' => 'SPIP exixe a extensi&oacute;n php&nbsp;:',
'install_login_base_hebergeur' => 'Login de conexi&oacute;n atribu&iacute;do polo aloxador',
'install_nom_base_hebergeur' => 'Nome da base atribu&iacute;da polo aloxador&nbsp;:',
'install_pas_table' => 'Base actualemente sen t&aacute;boas',
'install_pass_base_hebergeur' => 'Chave de conexi&oacute;n atribu&iacute;da polo aloxador',
'install_php_version' => 'Versi&amp;oacute;n de PHP @version@ insuficiente (m&amp;iacute;nima = @minimum@)',
'install_select_langue' => 'Selecciona un idioma e preme o bot&oacute;n &laquo;seguinte&raquo; para comezar co proceso de instalaci&oacute;n.',
'install_select_type_db' => 'Indique o tipo de base de datos&nbsp;:',
'install_select_type_mysql' => 'MySQL',
'install_select_type_pg' => 'PostgreSQL',
'install_select_type_sqlite2' => 'SQLite 2',
'install_select_type_sqlite3' => 'SQLite 3',
'install_serveur_hebergeur' => 'Servidor da base de datos atribu&iacute;da polo aloxador',
'install_table_prefix_hebergeur' => 'Prefixo de t&aacute;boa atribu&iacute;do polo aloxador&nbsp;:',
'install_tables_base' => 'T&aacute;boas da base',
'install_types_db_connus' => 'SPIP pode utilizar <b>MySQL</b> (o m&aacute;is maioritario), <b>PostgreSQL</b> e <b>SQLite</b>.',
'install_types_db_connus_avertissement' => 'Atenci&oacute;n&nbsp;: certos m&oacute;dulos (plugins) non funcionan sen&oacute;n con MySQL',
'intem_redacteur' => 'redactor/a',
'intitule_licence' => 'Licenza',
'item_accepter_inscriptions' => 'Aceptar as inscrici&oacute;ns',
'item_activer_forum_administrateur' => 'Activar o foro do equipo de xesti&oacute;n',
'item_activer_messages_avertissement' => 'Activar as mensaxes de aviso',
'item_administrateur_2' => 'Equipo de xesti&oacute;n',
'item_afficher_calendrier' => 'Mostrar no calendario',
'item_ajout_mots_cles' => 'Permitir palabras chave nos foros',
'item_autoriser_documents_joints' => 'Autorizar os documentos adxuntos cos artigos',
'item_autoriser_documents_joints_rubriques' => 'Autorizar os documentos nos temas',
'item_autoriser_selectionner_date_en_ligne' => 'Permite seleccionar a data de cada documento',
'item_autoriser_syndication_integrale' => 'Difundir integramente os artigos nos ficheiros de subscrici&oacute;n',
'item_bloquer_liens_syndiques' => 'Bloquear as ligaz&oacute;ns afiliadas para validaci&oacute;n',
'item_breve_refusee' => 'NON - Breve rexeitada',
'item_breve_validee' => 'S&iacute; - Breve validada',
'item_choix_administrateurs' => 'o equipo de xesti&oacute;n',
'item_choix_generation_miniature' => 'Crear automaticamente as miniaturas das imaxes.',
'item_choix_non_generation_miniature' => 'Non crear miniaturas das imaxes.',
'item_choix_redacteurs' => 'o equipo de redacci&oacute;n',
'item_choix_visiteurs' => 'as visitas do web p&uacute;blico',
'item_compresseur' => 'Activar a compactaci&oacute;n',
'item_config_forums_prive_global' => 'Activar o foro dos redactores',
'item_config_forums_prive_objets' => 'Activar estes foros',
'item_creer_fichiers_authent' => 'Crear os ficheiros &laquo;.htpasswd&raquo;',
'item_desactiver_forum_administrateur' => 'Desactivar o foro do equipo de xesti&oacute;n',
'item_gerer_annuaire_site_web' => 'Xestionar unha gu&iacute;a de webs',
'item_gerer_statistiques' => 'Xestionar as estat&iacute;sticas',
'item_limiter_recherche' => 'Limitar a procura &aacute;s informaci&oacute;ns contidas neste web',
'item_login' => 'Identificador',
'item_messagerie_agenda' => 'Activar a mensaxer&iacute;a e a axenda',
'item_mots_cles_association_articles' => '&oacute;s artigos',
'item_mots_cles_association_breves' => '&aacute;s breves',
'item_mots_cles_association_rubriques' => '&oacute;s temas',
'item_mots_cles_association_sites' => 'aos webs referidos ou afiliados.',
'item_non' => 'Non',
'item_non_accepter_inscriptions' => 'Non aceptar as inscrici&oacute;ns',
'item_non_activer_messages_avertissement' => 'Sen mensaxes de aviso',
'item_non_afficher_calendrier' => 'Non mostrar no calendario',
'item_non_ajout_mots_cles' => 'Prohibir o uso de palabras chave nos foros',
'item_non_autoriser_documents_joints' => 'Non permitir documentos nos artigos',
'item_non_autoriser_documents_joints_rubriques' => 'Non permitir documentos nos temas',
'item_non_autoriser_selectionner_date_en_ligne' => 'A data dos documentos resulta ser aquela que indica cano foi engadida no web',
'item_non_autoriser_syndication_integrale' => 'Non difundir sen&oacute;n un resumo',
'item_non_bloquer_liens_syndiques' => 'Non bloquear as ligaz&oacute;ns afiliadas',
'item_non_compresseur' => 'Desactivar a compactaci&oacute;n',
'item_non_config_forums_prive_global' => 'Desactivar o foro dos redactores',
'item_non_config_forums_prive_objets' => 'Desactivar estes foros',
'item_non_creer_fichiers_authent' => 'Non crear estes ficheiros',
'item_non_gerer_annuaire_site_web' => 'Desactivar o directorio/gu&iacute;a de webs',
'item_non_gerer_statistiques' => 'Non xestionar as estat&iacute;sticas',
'item_non_limiter_recherche' => 'Estender a procura &oacute; contido dos webs referidos',
'item_non_messagerie_agenda' => 'Desactivar a mensaxer&iacute;a e a axenda',
'item_non_publier_articles' => 'Non publicar os artigos antes da data de publicaci&oacute;n fixada.',
'item_non_utiliser_breves' => 'Non usar as breves',
'item_non_utiliser_config_groupe_mots_cles' => 'Non usar a configuraci&oacute;n avanzada dos grupos de palabras chave',
'item_non_utiliser_moteur_recherche' => 'Non usar o motor',
'item_non_utiliser_mots_cles' => 'Non usar as palabras chave',
'item_non_utiliser_syndication' => 'Non usar a afiliaci&oacute;n autom&aacute;tica',
'item_nouvel_auteur' => 'Novo/a autor/a',
'item_nouvelle_breve' => 'Nova breve',
'item_nouvelle_rubrique' => 'Novo tema',
'item_oui' => 'S&iacute;',
'item_publier_articles' => 'Publicar os artigos, sen importar a s&uacute;a data de publicaci&oacute;n.',
'item_reponse_article' => 'Resposta &oacute; artigo',
'item_utiliser_breves' => 'Empregar as breves',
'item_utiliser_config_groupe_mots_cles' => 'Empregar a configuraci&oacute;n avanzada dos grupos de palabras chave',
'item_utiliser_moteur_recherche' => 'Empregar o motor de procura',
'item_utiliser_mots_cles' => 'Empregar as palabras chave',
'item_utiliser_syndication' => 'Empregar a afiliaci&oacute;n autom&aacute;tica',
'item_visiteur' => 'visitante',

// J
'jour_non_connu_nc' => 'non consta',

// L
'lien_ajout_destinataire' => 'Engadir destinatari@',
'lien_ajouter_auteur' => 'Engadir autor/a',
'lien_ajouter_participant' => 'Engadir participante',
'lien_email' => 'correo-e.',
'lien_forum_public' => 'Xestionar o foro p&uacute;blico deste artigo',
'lien_mise_a_jour_syndication' => 'Po&ntilde;er ao d&iacute;a agora',
'lien_nom_site' => 'NOME DO WEB:',
'lien_nouvelle_recuperation' => 'Tentar unha nova recuperaci&oacute;n dos datos',
'lien_reponse_article' => 'Responder ao artigo',
'lien_reponse_breve' => 'Resposta &aacute; breve',
'lien_reponse_breve_2' => 'Resposta &aacute; breve',
'lien_reponse_rubrique' => 'Resposta &oacute; tema',
'lien_reponse_site_reference' => 'Resposta ao web referido:',
'lien_retirer_auteur' => 'Retirar esta persoa',
'lien_retrait_particpant' => 'retirar participante',
'lien_site' => 'web',
'lien_supprimer_rubrique' => 'Suprimir este tema',
'lien_tout_deplier' => 'Despregalo todo',
'lien_tout_replier' => 'Repregalo todo',
'lien_tout_supprimer' => 'Suprimir todo',
'lien_trier_nom' => 'Ordear por nome',
'lien_trier_nombre_articles' => 'Ordear por n&uacute;mero de artigos',
'lien_trier_statut' => 'Ordear por categor&iacute;a',
'lien_voir_en_ligne' => 'VER EN LI&Ntilde;A:',
'logo_article' => 'LOGO DO ARTIGO',
'logo_auteur' => 'LOGO DESTA PERSOA',
'logo_breve' => 'LOGO DA BREVE',
'logo_mot_cle' => 'LOGO DA PALABRA CHAVE',
'logo_rubrique' => 'LOGO DO TEMA',
'logo_site' => 'LOGO DESTE WEB',
'logo_standard_rubrique' => 'LOGO ESTANDAR DOS TEMAS',
'logo_survol' => 'LOGO DE INTERCAMBIO',

// M
'menu_aide_installation_choix_base' => 'Elixe a t&uacute;a base',
'module_fichier_langue' => 'Ficheiro de lingua',
'module_raccourci' => 'Recurso',
'module_texte_affiche' => 'Texto fixado',
'module_texte_explicatif' => 'Pode inserir os recursos seguintes dentro dos esqueletos do seu web p&uacute;blico. Ser&aacute;n automaticamente traducidos &aacute;s diferentes linguas para as que existe un ficheiro de lingua.',
'module_texte_traduction' => 'O ficheiro de lingua &laquo;&nbsp;@module@&nbsp;&raquo; est&aacute; dispo&ntilde;ible en&nbsp;:',
'mois_non_connu' => 'desco&ntilde;ecido',

// N
'nouvelles_versions' => 'Est&aacute;n dispo&ntilde;&iacute;beis novas versi&oacute;ns de SPIP',

// O
'onglet_contenu' => 'Contido',
'onglet_declarer_une_autre_base' => 'Declarar algunha outra base de datos',
'onglet_discuter' => 'Discutir',
'onglet_documents' => 'Documentos',
'onglet_interactivite' => 'Interactividade',
'onglet_proprietes' => 'Propiedades',
'onglet_repartition_actuelle' => 'actualmente',
'onglet_sous_rubriques' => 'Subsecci&oacute;ns',
'ortho_ajouter_ce_mot' => 'Engadir a palabra ao dicionario',
'ortho_aucune_suggestion' => 'Non hai suxesti&oacute;n relacionada con este termo',
'ortho_avis_privacy' => 'Un comprobador ortogr&aacute;fico foi integrado en SPIP. De todas maneiras, antes de o activar, lea con atenci&oacute;n o par&aacute;grafo seguinte&nbsp;:',
'ortho_avis_privacy2' => 'Para comprobar a ortograf&iacute;a dun texto, o web vai enviar a lista de termos para comprobar a un dos &laquo;&nbsp;servidores d\'ortograf&iacute;a&nbsp;&raquo; externos que po&ntilde;en &aacute; s&uacute;a disposici&oacute;n varios membros da comunidade SPIP. As verbas son enviadas con desorde co fin de asegurar un m&iacute;nimo de confidencialidade. Se vostede ten reservas cos seus datos, non active esta opci&oacute;n (e retire todo dato persoal do web).',
'ortho_ce_mot_connu' => 'Este termo est&aacute; recollido no dicionario do web',
'ortho_dico_absent' => 'Non se atopou ning&uacute;n dicionario para esta  lingua',
'ortho_mode_demploi' => 'Os termos non reco&ntilde;ecidos est&aacute;n subli&ntilde;ados en vermello. Pode premer sobre cada verba para ver suxesti&oacute;ns de correcci&oacute;n',
'ortho_mots_a_corriger' => 'Termos para corrixir',
'ortho_orthographe' => 'Ort&oacute;grafo',
'ortho_supprimer_ce_mot' => 'Sacar este termo do dicionario',
'ortho_trop_de_fautes' => 'Atenci&oacute;n&nbsp;: o seu texto cont&eacute;n demasiadas faltas, non se suxire ningunha correcci&oacute;n co fin de non sobrecargar o sistema.',
'ortho_verif_impossible' => 'O sistema non pode comprobar a ortograf&iacute;a deste texto.',
'ortho_verifier' => 'Comprobar a ortograf&iacute;a',

// P
'page_pas_proxy' => 'Esta p&aacute;xina non debe pasar por un proxy',
'pas_de_proxy_pour' => 'Segundo a s&uacute;a necesidade, indique as m&aacute;quinas ou dominios para os cales este proxy non debe ser aplicado (por exemplo&nbsp;: @exemple@)',
'plugin_charge_paquet' => 'Carga do paquete @name@',
'plugin_charger' => 'Descargar',
'plugin_erreur_charger' => 'erro&nbsp;: resulta imposible cargar @zip@',
'plugin_erreur_droit1' => 'O cartafol <code>@dest@</code> non &eacute; accesible para escritura.',
'plugin_erreur_droit2' => 'Verifique os dereitos deste cartafol (e crealos (no caso de ser necesario), ou instalar o ficheiros por FTP.',
'plugin_erreur_zip' => 'echec pclzip&nbsp;: erro @status@',
'plugin_etat_developpement' => 'en desenvolvemento',
'plugin_etat_experimental' => 'experimental',
'plugin_etat_stable' => 'est&aacute;bel',
'plugin_etat_test' => 'en test',
'plugin_impossible_activer' => 'Resulta imposible activar o plugin @plugin@',
'plugin_info_automatique1' => 'Se quere autorizar a instalaci&oacute;n autom&aacute;tica de m&oacute;dulos (plugins)&nbsp;:',
'plugin_info_automatique1_lib' => 'Se desexa autorizar a instalaci&oacute;n autom&aacute;tica desta biblioteca, vexa&nbsp;:',
'plugin_info_automatique2' => 'Crear un cartafol <code>@rep@</code>&nbsp;;',
'plugin_info_automatique3' => 'verificar que o servidor ten permisos para escribir neste cartafol.',
'plugin_info_automatique_creer' => 'crear na ra&iacute;z do web.',
'plugin_info_automatique_exemples' => 'exemplos&nbsp;:',
'plugin_info_automatique_ftp' => 'Pode instalar os m&oacute;dulos, por FTP, no cartafol <tt>@rep@</tt>',
'plugin_info_automatique_lib' => 'Certos m&oacute;dulos necesitan tam&eacute;n poder descargar no cartafol <code>lib/</code>, que deber&aacute; ser creado se for preciso na ra&iacute;z no web.',
'plugin_info_automatique_liste' => 'A s&uacute;a listaxe de m&oacute;dulos&nbsp;:',
'plugin_info_automatique_liste_officielle' => 'os m&oacute;dulos oficiais',
'plugin_info_automatique_liste_update' => 'Actualizar as listaxes',
'plugin_info_automatique_ou' => 'ou...',
'plugin_info_automatique_select' => 'Seleccione a seguir un m&oacute;dulo&nbsp;: SPIP  descargarao e instalarao no cartafol <code>@rep@</code>&nbsp;; si o m&oacute;dulo xa existe ser&aacute; actualizado.',
'plugin_info_extension_1' => 'As extensi&oacute;ns seguintes c&aacute;rganse e act&iacute;vanse no cartafol @extensions@.',
'plugin_info_extension_2' => 'Non son desactivables',
'plugin_info_telecharger' => 'descargar desde @url@ e instalalo no cartafol @rep@',
'plugin_librairies_installees' => 'Librar&iacute;as instaladas',
'plugin_necessite_lib' => 'Este m&oacute;dulo necesita a librar&iacute;a @lib@',
'plugin_necessite_plugin' => 'Necesita o plugin @plugin@ na s&uacute;a version @version@ m&iacute;nimo.',
'plugin_necessite_spip' => 'Necesita SPIP na s&uacute;a versi&oacute;n @version@ como m&iacute;nimo.',
'plugin_source' => 'fonte:&nbsp;',
'plugin_titre_automatique' => 'Instalaci&oacute;n autom&aacute;tica',
'plugin_titre_automatique_ajouter' => 'Engadir m&oacute;dulos',
'plugin_titre_installation' => 'Instalaci&oacute;n do m&oacute;dulo @plugin@',
'plugin_zip_active' => 'Contin&uacute;e para activalo',
'plugin_zip_adresse' => 'indique seguidamente o enderezo dun ficheiro zip de m&oacute;dulo para descargar, ou mesmo o enderezo dunha lista de m&oacute;dulos (plugins).',
'plugin_zip_adresse_champ' => 'Enderezo do m&oacute;dulo ou da listaxe&nbsp;',
'plugin_zip_content' => 'cont&eacute;n os ficheiros seguintes (@taille@),<br />listos para instalasr no cartafol <code>@rep@</code>',
'plugin_zip_installe_finie' => 'O ficheiro @zip@ foi descomprimido e instalado.',
'plugin_zip_installe_rep_finie' => 'O ficheiro @zip@ foi descomprimido e instalado no cartafol @rep@',
'plugin_zip_installer' => 'Agora p&oacute;deo instalar.',
'plugin_zip_telecharge' => 'O ficheiro @zip@ foi descargado',
'plugins_actif_aucun' => 'Non hai ning&uacute;n m&oacute;dulo activado.',
'plugins_actif_un' => 'Activouse un m&oacute;dulo.',
'plugins_actifs' => '@count@ m&oacute;dulos activados.',
'plugins_actifs_liste' => 'M&oacute;dulos activos',
'plugins_compte' => '@count@ m&oacute;dulos',
'plugins_disponible_un' => 'Un m&oacute;dulo dispo&ntilde;ible',
'plugins_disponibles' => '@count@ m&oacute;dulos dispo&ntilde;ibles.',
'plugins_erreur' => 'Erro nos m&oacute;dulos : @plugins@',
'plugins_liste' => 'Lista de m&oacute;dulos',
'plugins_liste_extensions' => 'Extensi&oacute;ns',
'plugins_recents' => 'M&oacute;dulos recentes.',
'plugins_vue_hierarchie' => 'Xerarqu&iacute;a',
'plugins_vue_liste' => 'Listaxe',
'protocole_ldap' => 'Versi&amp;oacute;n do protocolo :',

// R
'repertoire_plugins' => 'Repertorio&nbsp;:',

// S
'sans_heure' => 'sen hora',
'sauvegarde_fusionner' => 'Fusionar a base de datos actual e a copia de seguridade',
'sauvegarde_fusionner_depublier' => 'Despublicar os obxectos fusionados',
'sauvegarde_url_origine' => 'Eventualemente, URL do web de orixe :',
'statut_admin_restreint' => '(admin restrinxido)',
'syndic_choix_moderation' => 'Que facer das vindeiras ligaz&oacute;ns que prove&ntilde;an deste web&nbsp;?',
'syndic_choix_oublier' => 'Que facer das ligaz&oacute;ns que xa non figuran no ficheiro de subscrici&oacute;n&nbsp;?',
'syndic_choix_resume' => 'Alg&uacute;ns webs difunden o texto completo dos artigos. No caso de que isto estea dispo&ntilde;&iacute;bel desexa sindicalo&nbsp;:',
'syndic_lien_obsolete' => 'ligaz&oacute;n obsoleta',
'syndic_option_miroir' => 'bloquealas automaticamente',
'syndic_option_oubli' => 'borralas (tras @mois@&nbsp;mois)',
'syndic_option_resume_non' => 'o contido completo dos artigos (en formato HTML)',
'syndic_option_resume_oui' => 'un simple resumo (en formato de texto)',
'syndic_options' => 'Opci&oacute;ns da subscrici&oacute;n&nbsp;:',

// T
'taille_cache_image' => 'As imaxes calculadas automaticamente por SPIP (vi&ntilde;etas dos documentos, t&iacute;tulos presentados so a forma gr&aacute;fica, funci&oacute;ns matem&aacute;ticas en formato TeX...) ocupan no directorio @dir@ un total de @taille@.',
'taille_cache_infinie' => 'Neste web non se preveu limitaci&oacute;n de tama&ntilde;o do directorio da memoria cach&eacute;.',
'taille_cache_maxi' => 'SPIP est&aacute; a tentar limitar o tama&ntilde;o do directorio da cach&eacute; deste web en volta de <b>@octets@</b> de datos.',
'taille_cache_octets' => 'O tama&ntilde;o da cach&eacute; &eacute; actualmente de  @octets@.',
'taille_cache_vide' => 'A cach&eacute; est&aacute; baleira',
'taille_repertoire_cache' => 'Tama&ntilde;o do directorio de memoria cach&eacute;',
'text_article_propose_publication' => 'Artigo proposto para publicaci&oacute;n.',
'text_article_propose_publication_forum' => 'Non dubide avisar a trav&eacute;s do foro asociado a este artigo (a p&eacute; de p&aacute;xina).',
'texte_acces_ldap_anonyme_1' => 'Alg&uacute;ns servidores LDAP non aceptan ning&uacute;n acceso an&oacute;nimo. En tal caso hai que especificar un identificador de acceso inicial para poder procurar informaci&oacute;ns na gu&iacute;a. Na meirande parte dos casos poder&aacute;s deixar os seguintes campos baleiros.',
'texte_admin_effacer_01' => 'Este comando elimina <i>todo</i> o contido da base de datos,
		incluindo <i>todos</i> os accesos dos equipos de xesti&oacute;n e de redacci&oacute;n.
		Logo de executa.lo, ter&aacute;s que lanzar de novo a instalaci&oacute;n do SPIP para crear unha
		nova base e un novo acceso de administraci&oacute;n.',
'texte_admin_effacer_stats' => 'Este comando borra todos os datos ligados &aacute;s estat&iacute;sticas de visita do web, e incl&uacute;e a popularidade dos artigos.',
'texte_admin_tech_01' => 'Esta opci&oacute;n permite gardar o contido da base nun ficheiro que ser&aacute; almaceado no directorio @dossier@. Non esqueza tam&eacute;n gardar o directorio @img@ &iacute;ntegro, que &eacute; o que cont&eacute;n as imaxes e os documentos anexos empregados nos artigos e nas secci&oacute;ns.',
'texte_admin_tech_02' => 'Atenci&oacute;n!: esta copia de seguridade S&Oacute; poder&aacute; ser restaurada  nun web que te&ntilde;a instalada a MESMA versi&oacute;n de SPIP. Daquela de ningunha maneira &eacute; conveniente &laquo;&nbsp;baleirar a base&nbsp;&raquo; coa esperanza de reinstalar a copia de seguridade logo da actualizaci&oacute;n...Consulte
  <a href="@spipnet@">a documentaci&oacute;n de SPIP</a>.',
'texte_admin_tech_03' => 'Pode escoller gardar o ficheiro en formato comprimido, para optimizar
  a transferencia ou a copia nun servidor de copias de seguridade, e para aforrar espazo no disco.',
'texte_admin_tech_04' => 'Nun intento de fusi&oacute;n con outra base, pode limitar a copia de seguridade &aacute; secci&oacute;n:',
'texte_adresse_annuaire_1' => '(Se a s&uacute;a gu&iacute;a/directorio foi aloxada na mesma m&aacute;quina ca este
  web, seguramente ser&aacute; &laquo;localhost&raquo;.)',
'texte_ajout_auteur' => '@ seguinte autor/a foi engadido ao artigo:',
'texte_annuaire_ldap_1' => 'Se ten acceso a unha gu&iacute;a (LDAP), p&oacute;dea empregar para importar
  automaticamente usuarios con SPIP.',
'texte_article_statut' => 'Este artigo est&aacute;:',
'texte_article_virtuel' => 'Artigo virtual',
'texte_article_virtuel_reference' => '<b>Artigo virtual:</b> artigo referido no teu web SPIP,
  mais redirixido cara a outro URL. Para eliminar a redirecci&oacute;n, elimina o URL aqu&iacute;.',
'texte_aucun_resultat_auteur' => 'Ning&uacute;n resultado de "@cherche_auteur@"',
'texte_auteur_messagerie' => 'Este web pode indicar permanentemente a lista de redactores que est&aacute;n conectados nun intre, o que lle permite intercambiar mensaxes en directo (cando a mensaxer&iacute;a habilitada). Pode decidir non aparecer nesta lista (ser&aacute; &laquo;invisible&raquo; para os demais).',
'texte_auteur_messagerie_1' => 'Este web permite o intercambio de mensaxes e a constituci&oacute;n de foros de discusi&oacute;n privados entre os participantes do web. Pode decidir non participar nestes parladoiros.',
'texte_auteurs' => 'A AUTOR&Iacute;A',
'texte_breves' => 'As breves son textos curtos e simples que permeten
  publicar rapidamente informaci&oacute;ns concisas, xestionar unha
  revista de prensa, un calendario de eventos...',
'texte_choix_base_1' => 'Elixe a t&uacute;a base:',
'texte_choix_base_2' => 'O servidor SQL cont&eacute;n varias bases de datos.',
'texte_choix_base_3' => '<b>Seleccione</b> aqu&amp;iacute; a que lle dese o seu provedor:',
'texte_choix_table_prefix' => 'Prefixo das t&aacute;boas&nbsp;:',
'texte_commande_vider_tables_indexation' => 'empregue este comando para baleirar as t&aacute;boas
  de indexado empregadas polo motor de procura integrado no Spip.
  Isto permite ga&ntilde;ar espazo en disco.',
'texte_comment_lire_tableau' => 'O rango do artigo,
		na clasificaci&oacute;n por popularidade, est&aacute; indicado &aacute; marxe;
		a popularidade do artigo (unha estimaci&oacute;n do n&uacute;mero
		de visitas coti&aacute;s que ter&aacute; se o ritmo actual de
		consulta se mant&eacute;n) e o n&uacute;mero de visitas recibidas
		dende o principio son amosadas no bolo que
		aparece cando pasas co rato por riba do t&iacute;tulo.',
'texte_compacter_avertissement' => 'Atenci&oacute;n para non activar estas opci&oacute;ns durante o desenvolvemento do seu web: os elementos compactados perden toda a s&uacute;a lexibilidade.',
'texte_compacter_script_css' => 'SPIP pode compactar os scripts javascript e as follas de estilo CSS, para rexistralos nas fichas est&aacute;ticas ; iso acelera a presentaci&oacute;n do web.',
'texte_compresse_ou_non' => '(comprimido ou non)',
'texte_compresseur_page' => 'SPIP pode comprimir automaticamente cada p&aacute;xina que env&iacute;a ao
visitante do web. Esta regraxe permite optimizar o ancho de banda (o 
web &eacute; m&aacute;is r&aacute;pido ao seguirse unha ligaz&oacute;n de baixa velocidade), mais
demanda m&aacute;is potencia do servidor.',
'texte_compte_element' => '@count@ elemento',
'texte_compte_elements' => '@count@ elementos',
'texte_config_groupe_mots_cles' => 'Quere activar a configuraci&amp;oacute;n avanzada das palabras clave,
  para indicar, por exemplo que se pode seleccionar unha palabra &amp;uacute;nica
  por grupo, que un grupo &amp;eacute; importante...&nbsp;?',
'texte_conflit_edition_correction' => 'Controle a seguir as diferenzas entre as d&uacute;as versi&oacute;ns do texto; pode tam&eacute;n copiar as s&uacute;as modificaci&oacute;ns e volver comezar.',
'texte_connexion_mysql' => 'Consulte os datos que lle proporcionou o seu aloxador: deber&aacute; encontrar a&iacute; o servidor de bases de datos do que disp&oacute;n e os identificadores para conectar con el (claves de conexi&oacute;n).',
'texte_contenu_article' => '(Contido do artigo en poucas palabras.)',
'texte_contenu_articles' => 'Dependendo da maquetaci&oacute;n adoptada para o seu web, pode decidir
  non empregar certos elementos dos artigos. Use esta lista para indicar cales ser&aacute;n os elementos dispo&ntilde;ibles.',
'texte_crash_base' => 'Se a base de datos ten alg&uacute;n problema, podes tentar unha reparaci&oacute;n autom&aacute;tica.',
'texte_creer_rubrique' => 'Antes de poder escribir artigos<br/>, ten que crear un tema ou secci&amp;oacute;n.',
'texte_date_creation_article' => 'DATA DE CREACI&Oacute;N DO ARTIGO',
'texte_date_publication_anterieure' => 'Data de redacci&oacute;n anterior&nbsp;:',
'texte_date_publication_anterieure_nonaffichee' => 'Non mostrar data de redacci&oacute;n anterior.',
'texte_date_publication_article' => 'DATA DE PUBLICACI&Oacute;N EN LI&Ntilde;A&nbsp;:',
'texte_descriptif_petition' => 'Descrici&oacute;n da petici&oacute;n',
'texte_descriptif_rapide' => 'Descrici&oacute;n r&aacute;pida',
'texte_documents_joints' => 'Pode autorizar o acompa&ntilde;amento de documentos (textos, imaxes,
  multimedia, etc.) aos artigos e/ou aos temas. Estes ficheiros
  poden aparecer referidos no artigo ou mostrados por separado.<p>',
'texte_documents_joints_2' => 'Este axuste non impide a inserci&oacute;n de imaxes directamente nos artigos.',
'texte_effacer_base' => 'Eliminar a base de datos SPIP',
'texte_effacer_donnees_indexation' => 'Eliminar os datos de indexaci&oacute;n',
'texte_effacer_statistiques' => 'Borrar as estat&iacute;sticas',
'texte_en_cours_validation' => 'Os artigos e as breves de aqu&iacute; embaixo foron propostos para a s&uacute;a publicaci&oacute;n.',
'texte_en_cours_validation_forum' => 'Non dubide avisar a trav&eacute;s dos foros que levan engadidos.',
'texte_enrichir_mise_a_jour' => 'P&oacute;dese mellorar a presentaci&oacute;n do texto empregando os &laquo;atallos tipogr&aacute;ficos&raquo;.',
'texte_fichier_authent' => '<b>SPIP ten que crear os ficheiros especiais <tt>.htpasswd</tt>
  e <tt>.htpasswd-admin</tt> no cartafol @dossier@?</b><p>
  Estes ficheiros p&oacute;denlle servir para restrinxir o acceso, tanto aos autores
  coma aos administradores a outras partes do seu web (ao programa
  externo de estat&iacute;sticas, por exemplo).</p><p>
  Se non o utiliza, pode deixar esta opci&oacute;n
 co seu valor predeterminado (non crear
estes ficheiros).</p>',
'texte_informations_personnelles_1' => 'O sistema vaiche crear agora un acceso personalizado ao web',
'texte_informations_personnelles_2' => '(Nota: se se trata dunha reinstalaci&oacute;n, e o teu acceso vai sen atrancos, podes',
'texte_introductif_article' => '(Texto introdutorio do artigo.)',
'texte_jeu_caractere' => 'Acons&eacute;llase empregar, no seu web, o alfabeto universal (<tt>utf-8</tt>)&nbsp;: isto permite mostrar textos en todas as linguas, e non presenta problemas de compatibilidade cos navegadores modernos.',
'texte_jeu_caractere_2' => 'Atenci&oacute;n : este axuste non ten efecto retroactivo. Daquela, non se produce a conversi&oacute;n dos textos xa rexistrados na base de datos.',
'texte_jeu_caractere_3' => 'O seu web est&aacute; actualmente instalado co xogo de car&aacute;cteres&nbsp;:',
'texte_jeu_caractere_4' => 'Se iso non corresponde coa realidade dos seus datos (logo, por exemplo, dunha restauraci&oacute;n da base de datos), ou se <em>vostede principia neste web</em> e quere partir doutro xogo de car&aacute;cteres, ind&iacute;queo por favor aqu&iacute;&nbsp;:',
'texte_jeu_caractere_conversion' => 'Nota&nbsp;: pode decidir converter dunha soa vez o conxunto dos texto do seu web (artigos, breves, foros, etc.) ao alfabeto <tt>utf-8</tt>, se accede en <a href="@url@">&aacute; p&aacute;xina de conversi&oacute;n a utf-8</a>.',
'texte_lien_hypertexte' => '(Se a s&uacute;a mensaxe se refire a un artigo publicado no web, ou a
  unha p&aacute;xina con que forneza m&aacute;is informaci&oacute;n, indica aqu&iacute; o t&iacute;tulo da p&aacute;xina e o seu enderezo URL.)',
'texte_liens_sites_syndiques' => 'As ligaz&oacute;ns procedentes dos webs afiliados
  poden ser bloquedas a priori; o axuste aqu&iacute; embaixo indica a configuraci&oacute;n
  por defecto dos web afiliados logo da s&uacute;a creaci&oacute;n.
  De todos os xeitos despois &eacute; posible desbloquear cada ligaz&oacute;n individualmente,
  ou escoller, web por web, o bloqueo das ligaz&oacute;ns futuras de tal ou cal web.',
'texte_login_ldap_1' => '(Deixar baleiro para un acceso an&oacute;nimo, ou po&ntilde;er a v&iacute;a completa,
  por exemplo &laquo;<tt>uid=maricarmen, ou=users, dc=meu-dominio, dc=com</tt>&raquo;.)',
'texte_login_precaution' => 'Atenci&oacute;n! Este &eacute; o identificador co que se conectou.
  Empregue este formulario con precauci&oacute;n...',
'texte_message_edit' => 'Atenci&oacute;n: esta mensaxe pode ser modificada por calquera dos xestores,
e ser&aacute; visible para todo o equipo de redacci&oacute;n. Use os anuncios s&oacute; para avisar
  de eventos importantes da vida do web.',
'texte_messagerie_agenda' => 'A mensaxer&iacute;a perm&iacute;telles aos redactores do web comunicarse entre eles directamente no espazo privado do web. Est&aacute; asociado a unha axenda.',
'texte_messages_publics' => 'Mensaxes p&uacute;blicas do artigo:',
'texte_mise_a_niveau_base_1' => 'Acaba de por ao d&iacute;a os ficheiros do SPIP.
  Agora ten que actualizar a base de datos do web.',
'texte_modifier_article' => 'Modificar o artigo:',
'texte_moteur_recherche_active' => '<b>O motor de procuras est&aacute; activado.</b> empr&eacute;gueo
   cando queira proceder a un reindexado r&aacute;pido (trala restauraci&oacute;n dunha copia de seguridade,
  por exemplo). Saiba que os documentos modificados de xeito normal
  (dende a interface do SPIP) son reindexados automaticamente:
  este comando s&oacute; &eacute; &uacute;til excepcionalmente.',
'texte_moteur_recherche_non_active' => 'O motor de procura non est&aacute; activado.',
'texte_mots_cles' => 'As palabras chave permiten crear ligaz&oacute;ns tem&aacute;ticas entre os artigos
  sen depender do seu emprazamento dentro dos temas. P&oacute;dese, dende
  mellorar a navegaci&oacute;n do seu web, ata empregar as s&uacute;as propiedades
  para personalizar a presentaci&oacute;n dos artigos dentro dos seus esqueletos.',
'texte_mots_cles_dans_forum' => 'Quere permitir o emprego de palabras chave, seleccionables polos visitantes, nos foros do web p&uacute;blico? (Atenci&oacute;n: esta opci&oacute;n &eacute; relativamente complexa de empregar correctamente.)',
'texte_multilinguisme' => 'Se desexa crear artigos en varias linguas, cunha navegaci&oacute;n complexa, pode engadir un men&uacute; de selecci&oacute;n da lingua dos artigos e/ou das secci&oacute;ns, en funci&oacute;n da organizaci&oacute;n do seu web.',
'texte_multilinguisme_trad' => 'Pode igualmente activar un sistema de xesti&oacute;n de ligaz&oacute;ns entre as diferentes traduci&oacute;ns dun artigo.',
'texte_non_compresse' => '<i>non comprimido</i> (o teu servidor non soporta esta funcionalidade)',
'texte_non_fonction_referencement' => 'Pode preferir non usar esta funci&oacute;n autom&aacute;tica, e indicar &aacute; man os elementos concernintes a este web...',
'texte_nouveau_message' => 'Nova mensaxe',
'texte_nouveau_mot' => 'Nova palabra',
'texte_nouvelle_version_spip_1' => 'Instalaches unha nova versi&oacute;n de SPIP.',
'texte_nouvelle_version_spip_2' => 'Esta nova versi&oacute;n precisa unha posta ao d&iacute;a m&aacute;is completa que a habitual. De seres webm&aacute;ster do web, elimine o ficheiro @connect@ e retome a instalaci&oacute;n para po&ntilde;er ao d&iacute;a os par&aacute;metros de conexi&oacute;n &aacute; base de datos.<p> (NB.&nbsp;: se esqueceu os par&aacute;metros de conexi&oacute;n, b&oacute;telle un ollo ao ficheiro  @connect@ antes de borralo...)</p>',
'texte_operation_echec' => 'Volve &aacute; p&aacute;xina anterior, selecciona outra base ou crea unha nova. Verifica a informaci&oacute;n que che dera o teu aloxador.',
'texte_plus_trois_car' => 'm&aacute;is de 3 caracteres',
'texte_plusieurs_articles' => 'Atop&aacute;ron.se varias entradas para "@cherche_auteur@":',
'texte_port_annuaire' => '(En xeral, conv&eacute;n po&ntilde;er o valor indicado por defecto.)',
'texte_presente_plugin' => 'Esta p&aacute;xina lista os m&oacute;dulos dispo&ntilde;ibles no web. Pode activar os m&oacute;dulos necesarios marcando a caixa correspondente.',
'texte_proposer_publication' => 'Cando remate o seu artigo,<br />pode propor que sexa publicado.',
'texte_proxy' => 'Nalg&uacute;ns casos (intranet, redes protexidas...), os webs distantes (documentaci&oacute;n de SPIP, webs afiliados, etc. ) non son accesibles se non &eacute; por medio dun <i>proxy HTTP</i>. Chegado o caso, indique aqu&iacute; embaixo o seu enderezo, no formato @proxy_en_cours@.
  En xeral, deixar&aacute;; esta caixa baleira.',
'texte_publication_articles_post_dates' => 'Que comportamento debe adoptar o SPIP cos artigos nos
  que a data de publicaci&oacute;n foi fixada no futuro?',
'texte_rappel_selection_champs' => '[Lembre seleccionar correctamente este campo.]',
'texte_recalcul_page' => 'Se quere recalcular unha soa p&aacute;xina, vaia millor polo espazo p&uacute;blico e empregue o bot&oacute;n &laquo;recargar&raquo;.',
'texte_recapitiule_liste_documents' => 'Esta p&aacute;xina recolle a lista dos documentos introducidos nos temas. Para modificar as informaci&oacute;ns de cada documento, siga a ligaz&oacute;n cara &aacute; p&aacute;xina de tal tema.',
'texte_recuperer_base' => 'Reparar a base de datos',
'texte_reference_mais_redirige' => 'artigo referido no seu web SPIP, mais redirixido cara a outro URL.',
'texte_referencement_automatique' => '<b>Referencia automatizada dun web</b><br />Pode referir rapidamente un  web ao indicar aqu&iacute; embaixo o enderezo URL desexado, ou o enderezo do seu ficheiro de afiliaci&oacute;n. SPIP recuperar&aacute; automaticamente as informaci&oacute;ns concernintes a este lugar (t&iacute;tulo, descrici&oacute;n...).',
'texte_referencement_automatique_verifier' => 'Comprobe os datos fornecidos por <tt>@url@</tt> antes de rexistralos.',
'texte_requetes_echouent' => '<b>Cando algunhas petici&oacute;ns SQL fallan
 sistematicamente e sen raz&oacute;n aparente, &eacute; posible
 que a causa sexa a propia base de datos.
</b><p>
  SQL ten unha opci&oacute;n de reparaci&oacute;n das
 t&aacute;boas cando estas foron danadas por accidente.
  A&iacute; pode tentar esta reparaci&oacute;n; en caso de fallo, garde unha copia do resultado, que pode que conte&ntilde;a indicios do que non vai ben...<p>
  Se o problema persiste, p&oacute;&ntilde;ase en contacto co seu provedor de aloxamento.<p>',
'texte_restaurer_base' => 'Restaurar o contido dunha copia de seguridade da base',
'texte_restaurer_sauvegarde' => 'Esta opci&oacute;n permite restaurar unha copia de seguridade precedente
  feita da base. Para isto, o ficheiro da copia de seguridade ten que
  estar no cartafol @dossier@.
  Sexa prudente con esta funcionalidade&nbsp;: <b>as modificaci&oacute;ns e perdas eventuais, son
  irrevers&iacute;beis.</b>',
'texte_sauvegarde' => 'Gardar o contido da base',
'texte_sauvegarde_base' => 'Gardar a base',
'texte_sauvegarde_compressee' => 'A copia de seguridade ser&aacute; feita no ficheiro sen comprimir @fichier@.',
'texte_selection_langue_principale' => 'Pode seleccionar aqu&iacute; embaixo a &laquo;lingua principal&raquo; do web. Esta elecci&oacute;n non obriga (malo ser&iacute;a!) a escribir os artigos no idioma seleccionado, mais permite determinar:
  <ul><li>o formato por defecto das datas no web p&uacute;blico;</li>
  <li>a natureza do motor tipogr&aacute;fico que SPIP ten que empregar para a reproduci&oacute;n dos textos;</li>
  <li>a lingua empregada nos formularios do web p&uacute;blico;</li>
  <li>a lingua presentada por defecto no espazo privado.</li></ul>',
'texte_signification' => 'As barras escuras representan as entradas acumuladas (total dos apartados), as barras claras o n&uacute;mero de visitas para cada tema.',
'texte_sous_titre' => 'Subt&iacute;tulo',
'texte_statistiques_visites' => '(barras escuras:  domingo / curva escura: evoluci&oacute;n da media)',
'texte_statut_attente_validation' => 'agardando pola validaci&oacute;n',
'texte_statut_publies' => 'publicados en li&ntilde;a',
'texte_statut_refuses' => 'rexeitados',
'texte_suppression_fichiers' => 'Empregue este comando para suprimir todos os ficheiros presentes
  na cach&eacute; do Spip. Isto permite, por exemplo, forzar un novo c&aacute;lculo de todas as p&aacute;xinas cando se fagan
  grandes cambios gr&aacute;ficos ou de estrutura do web.',
'texte_sur_titre' => 'Sobret&iacute;tulo',
'texte_syndication' => 'P&oacute;dese recuperar automaticamente, e sempre que o sitio web o permita, 
  a s&uacute;a lista de novidades. Para isto, ten que activar a afiliaci&oacute;n.
  <blockquote><i>Alg&uacute;ns aloxadores desactivan esta funcionalidade;
  nese caso, non poder&aacute; empregar a afiliaci&oacute;n de contido
  dende o seu web.</i></blockquote>',
'texte_table_ok' => ': esta t&aacute;boa est&aacute; ben.',
'texte_tables_indexation_vides' => 'As t&aacute;boas de indexaci&oacute;n do motor est&aacute;n baleiras.',
'texte_tentative_recuperation' => 'Tentativa de reparaci&oacute;n',
'texte_tenter_reparation' => 'Tentar unha reparaci&oacute;n da base de datos',
'texte_test_proxy' => 'Para probar o proxy, indique o enderezo do web que queira testear.',
'texte_titre_02' => 'T&iacute;tulo:',
'texte_titre_obligatoire' => '<b>T&amp;iacute;tulo</b> [Obrigado]',
'texte_travail_article' => '@nom_auteur_modif@ traballou neste artigo hai @date_diff@ minutos',
'texte_travail_collaboratif' => 'Se &eacute; habitual que varias persoas traballen nun
  artigo ao mesmo tempo, o sistema pode mostrar os artigos 
  &laquo;abertos&raquo; recentemente, por mor de evitar as 
  modificaci&oacute;ns simult&aacute;neas. Esta opci&oacute;n est&aacute; 
  desactivada por defecto para evitar mostrar mensaxes de aviso intempestivas.',
'texte_trop_resultats_auteurs' => 'Resultados de m&aacute;is para "@cherche_auteur@"; por favor, afine a procura.',
'texte_type_urls' => 'Pode escoller aqu&iacute; o modo de calcular o enderezo das p&aacute;xinas.',
'texte_type_urls_attention' => 'Aviso, esta regraxe non funcionar&aacute; se o ficheiro @htaccess@ non est&aacute; correctamente instalado na ra&iacute;z do web.',
'texte_unpack' => 'descarga da &uacute;ltima versi&oacute;n',
'texte_utilisation_moteur_syndiques' => 'Cando emprega o motor de procura integrado
  no SPIP, pode efectuar as procuras nos webs e nos artigos afiliados
  de dous xeitos diferentes.
  <br />-  O m&aacute;is
 sinxelo consiste en buscar s&oacute;
 nos t&iacute;tulos e nas descrici&oacute;ns dos artigos.<br />-
  Un segundo m&eacute;todo, moito m&aacute;is potente, perm&iacute;telle
  a SPIP buscar, a maiores, no texto dos lugares afiliados&nbsp;. Se se referencia un web,
 daquela SPIP buscar&aacute; tam&eacute;n al&aacute;, no propio texto do web referido.',
'texte_utilisation_moteur_syndiques_2' => 'Este m&eacute;todo obriga a SPIP a visitar
  regularmente os webs referidos, o cal pode provocar unha lixeira perda de
  velocidade no seu propio web.',
'texte_vide' => 'baleiro',
'texte_vider_cache' => 'Baleirar a memoria cach&eacute;',
'titre_admin_effacer' => 'Mantemento t&eacute;cnico',
'titre_admin_tech' => 'Mantemento t&eacute;cnico',
'titre_admin_vider' => 'Mantemento t&eacute;cnico',
'titre_articles_syndiques' => 'Artigos afiliados extra&iacute;dos deste web',
'titre_breves' => 'As breves',
'titre_cadre_afficher_article' => 'Mostrar os artigos',
'titre_cadre_afficher_traductions' => 'Fixar o estado das traduci&oacute;ns para as seguintes linguas&nbsp;:',
'titre_cadre_ajouter_auteur' => 'ENGADIR UN/UNHA AUTOR/A:',
'titre_cadre_forum_administrateur' => 'Foro privado de xesti&oacute;n',
'titre_cadre_forum_interne' => 'Foro interno',
'titre_cadre_interieur_rubrique' => 'Dentro do tema',
'titre_cadre_numero_auteur' => 'AUTOR/A N&Uacute;MERO',
'titre_cadre_signature_obligatoire' => '<b>Sinatura</b> [Obrigado]<br />',
'titre_compacter_script_css' => 'Compactaci&oacute;n de scripts e CSS',
'titre_compresser_flux_http' => 'Compactaci&oacute;n do fluxo HTTP',
'titre_config_contenu_notifications' => 'Notificaci&oacute;ns',
'titre_config_contenu_prive' => 'No espazo privado',
'titre_config_contenu_public' => 'No web p&uacute;blico',
'titre_config_fonctions' => 'Configuraci&oacute;n do web',
'titre_config_forums_prive' => 'Foros do espazo privado',
'titre_config_groupe_mots_cles' => 'Configuraci&oacute;n dos grupos de palabras chave',
'titre_configuration' => 'Configuraci&oacute;n do web',
'titre_conflit_edition' => 'Conflito tras a edici&oacute;n',
'titre_connexion_ldap' => 'Opci&oacute;ns: <b>A s&uacute;a conexi&oacute;n LDAP</b>',
'titre_dernier_article_syndique' => '&Uacute;ltimos artigos afiliados',
'titre_documents_joints' => 'Documentos adxuntos',
'titre_evolution_visite' => 'Evoluci&oacute;n das visitas',
'titre_forum_suivi' => 'Seguimento dos foros',
'titre_gauche_mots_edit' => 'PALABRA N&Uacute;MERO:',
'titre_groupe_mots' => 'GRUPO DE PALABRAS:',
'titre_langue_article' => 'LINGUA DO ARTIGO',
'titre_langue_breve' => 'LINGUA DA BREVE',
'titre_langue_rubrique' => 'LINGUA DA SECCI&Oacute;N',
'titre_langue_trad_article' => 'LINGUA E TRADUCI&Oacute;NS DO ARTIGO',
'titre_les_articles' => 'OS ARTIGOS',
'titre_messagerie_agenda' => 'Mensaxer&iacute;a e axenda',
'titre_mots_cles_dans_forum' => 'Palabras chave nos foros do web p&uacute;blico',
'titre_mots_tous' => 'As palabras chave',
'titre_naviguer_dans_le_site' => 'Navegar no web...',
'titre_nouveau_groupe' => 'Novo grupo',
'titre_nouvelle_breve' => 'Nova breve',
'titre_nouvelle_rubrique' => 'Novo tema',
'titre_numero_rubrique' => 'TEMA N&Uacute;MERO:',
'titre_page_admin_effacer' => 'Mantemento t&eacute;cnico: borrar a base',
'titre_page_articles_edit' => 'Modificar: @titre@',
'titre_page_articles_page' => 'Os artigos',
'titre_page_articles_tous' => 'Todo o web',
'titre_page_auteurs' => 'Visitantes',
'titre_page_breves' => 'Breves',
'titre_page_breves_edit' => 'Modificar a breve: &laquo; @titre@ &raquo;',
'titre_page_calendrier' => 'Calendario @nom_mois@ @annee@',
'titre_page_config_contenu' => 'Configuraci&oacute;n do web',
'titre_page_config_fonctions' => 'Configuraci&oacute;n do web',
'titre_page_configuration' => 'Configuraci&oacute;n do web',
'titre_page_controle_petition' => 'Seguimento das petici&oacute;ns',
'titre_page_delete_all' => 'Supresi&oacute;n total e irreversible',
'titre_page_documents_liste' => 'Os documentos dos temas',
'titre_page_forum' => 'Foro de xesti&oacute;n',
'titre_page_forum_envoi' => 'Enviar unha mensaxe',
'titre_page_forum_suivi' => 'Seguimento dos foros',
'titre_page_index' => 'O teu espazo privado',
'titre_page_message_edit' => 'Redactar unha mensaxe',
'titre_page_messagerie' => 'A t&uacute;a mensaxer&iacute;a',
'titre_page_mots_tous' => 'Palabras chave',
'titre_page_recherche' => 'Resultados da procura de @recherche@',
'titre_page_sites_tous' => 'Os webs referidos',
'titre_page_statistiques' => 'Estat&iacute;sticas por temas',
'titre_page_statistiques_messages_forum' => 'Mensaxes de foro',
'titre_page_statistiques_referers' => 'Estat&iacute;sticas (ligaz&oacute;ns entrantes)',
'titre_page_statistiques_signatures_jour' => 'N&uacute;mero de sinaturas por d&iacute;a',
'titre_page_statistiques_signatures_mois' => 'N&uacute;mero de sinaturas por mes',
'titre_page_statistiques_visites' => 'Estat&iacute;sticas das visitas',
'titre_page_upgrade' => 'Posta ao d&iacute;a de SPIP',
'titre_publication_articles_post_dates' => 'Publicaci&oacute;n dos artigos con data posterior',
'titre_referencement_sites' => 'Referencia de webs e afiliaci&oacute;n',
'titre_referencer_site' => 'Referir o web:',
'titre_rendez_vous' => 'CITA:',
'titre_reparation' => 'Reparaci&oacute;n',
'titre_site_numero' => 'WEB N&Uacute;MERO:',
'titre_sites_proposes' => 'Os webs propostos',
'titre_sites_references_rubrique' => 'Os webs referenciados neste tema',
'titre_sites_syndiques' => 'Os webs afiliados',
'titre_sites_tous' => 'Os webs referidos',
'titre_suivi_petition' => 'Seguimento das petici&oacute;ns',
'titre_syndication' => 'Subscrici&oacute;n de webs',
'titre_type_urls' => 'Tipo de enderezos URL',
'tls_ldap' => 'Capa de seguridade de transporte (Transport Layer Security) :',
'tout_dossier_upload' => 'Todo o cartafol @upload@',
'trad_article_inexistant' => 'Non hai artigo que leve este n&uacute;mero.',
'trad_article_traduction' => 'Todas as versi&oacute;ns deste artigo&nbsp;:',
'trad_deja_traduit' => 'Erro: &eacute; imposible religar este artigo co n&uacute;mero solicitado.',
'trad_delier' => 'Non ligar xa este artigo a estas traduci&oacute;ns',
'trad_lier' => 'Este artigo &eacute; unha traduci&oacute;n do artigo n&uacute;mero&nbsp;:',
'trad_new' => 'Escribir unha nova traduci&oacute;n deste artigo',

// U
'upload_fichier_zip' => 'Arquivo ZIP',
'upload_fichier_zip_texte' => 'O ficheiro que pretende instalar &eacute; un arquivo Zip.',
'upload_fichier_zip_texte2' => 'Este ficheiro pode ser&nbsp;:',
'upload_info_mode_document' => 'Po&ntilde;er esta imaxe no portafolio',
'upload_info_mode_image' => 'Retirar esta imaxe do portafolio',
'upload_limit' => 'Este ficheiro &eacute; demasiado grande para o servidor&nbsp;; o tama&ntilde;o m&aacute;ximo autorizado en <i>upload</i> &eacute; de @max@.',
'upload_zip_conserver' => 'Conservar o arquivo tras a extracci&oacute;n',
'upload_zip_decompacter' => 'descompr&iacute;mase e cada elemento que conte&ntilde;a que sexa instalado no web. Os ficheiros que ser&aacute;n instalados son&nbsp;:',
'upload_zip_telquel' => 'instalado tal cal, dado que &eacute; un arquivo comprimido Zip&nbsp;;',
'upload_zip_titrer' => 'Titular consonte o patr&oacute;n de nome dos ficheiros.',
'utf8_convert_attendez' => 'Agarde un pouco de tempo e recargue esta p&aacute;xina.',
'utf8_convert_avertissement' => 'Vai converter o contido da s&uacute;a base de datos (artigos, breves, etc) do xogo de car&aacute;cteres <b>@orig@</b> ao xogo de car&aacute;cteres <b>@charset@</b>.',
'utf8_convert_backup' => 'Non esqueza antes de nada de facer unha salvagarda completa do seu web.  D&eacute;bese tam&eacute;n comprobar que os esqueletos e ficheiros de lingua sexan compatibles con @charset@.',
'utf8_convert_erreur_deja' => 'O seu web xa est&aacute; en car&aacute;cter @charset@, &eacute; in&uacute;til convertelo...',
'utf8_convert_erreur_orig' => 'Erro&nbsp;: o xogo de car&aacute;cteres @charset@ non est&aacute; soportado.',
'utf8_convert_termine' => 'Rematou!',
'utf8_convert_timeout' => '<b>Importante&nbsp;:</b> para o caso de que se produza <i>timeout</i> do servidor, recargue a p&aacute;xina at&eacute; que indique  &laquo;&nbsp;termin&eacute;&nbsp;&raquo;.',
'utf8_convert_verifier' => 'Agora debe baleirar a memoria temporal (cach&eacute;), e comprobar que todo vai ben nas p&aacute;xinas p&uacute;blicas do web. No caso de que haxa problemas graves, unha copia de salvagarda dos seus datos foi realizada (en formato SQL) no cartafol @rep@.',
'utf8_convertir_votre_site' => 'Converter o seu web a utf-8',

// V
'version' => 'Versi&oacute;n&nbsp;:',
'version_deplace_rubrique' => 'Movido de <b>&laquo;&nbsp;@from@&nbsp;&raquo;</b> a <b>&laquo;&nbsp;@to@&nbsp;&raquo;</b>.',
'version_initiale' => 'Versi&oacute;n inicial'
);

?>
